AccumulatorIndicator class

Accumulator Barriers.

Inheritance

Constructors

AccumulatorIndicator(Tick tick, {required double lowBarrier, required double highBarrier, required String highBarrierDisplay, required String lowBarrierDisplay, required String barrierSpotDistance, required int barrierEpoch, AccumulatorsActiveContract? activeContract, String? id, HorizontalBarrierStyle? style = const HorizontalBarrierStyle(labelShape: LabelShape.pentagon), HorizontalBarrierVisibility labelVisibility = HorizontalBarrierVisibility.normal})
Initializes a tick indicator.

Properties

activeContract AccumulatorsActiveContract?
Optional Active contract information.
final
annotationObject ↔ AccumulatorObject
Annotation Object.
getter/setter pairinherited
barrierEpoch int
The epoch of the tick that the barriers belong to.
final
barrierSpotDistance String
The price difference between the barrier and the tick quote.
final
hashCode int
The hash code for this object.
no setterinherited
highBarrier double
The high barrier value.
final
highBarrierDisplay String
The low barrier display value.
final
id String
The ID of this ChartData.
getter/setter pairinherited
isOnRange bool
Is this ChartAnnotation on the chart's epoch range.
getter/setter pairinherited
labelVisibility HorizontalBarrierVisibility
Tick quote label visibility behavior.
final
lowBarrier double
The low barrier value.
final
lowBarrierDisplay String
The high barrier display value.
final
maxValue double
Max quote in a frame.
no setterinherited
maxValueInFrame double?
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
minValue double
Min quote in a frame.
no setterinherited
minValueInFrame double?
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
previousObject ↔ AccumulatorObject?
Previous annotation object.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesPainter SeriesPainter<Series>?
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
style → ChartPaintingStyle?
The painting style of this Series.
finalinherited
tick Tick
The which this tick indicator will be pointing to.
final

Methods

createObject() → AccumulatorObject
Prepares the annotationObject of this ChartAnnotation.
override
createPainter() SeriesPainter<Series>
Is called whenever series is created to create its seriesPainter as well.
override
didUpdate(ChartData? oldData) bool
Will be called by the chart when it was updated.
inherited
getMaxEpoch() int?
Maximum epoch of this ChartData on the chart's X-Axis.
override
getMinEpoch() int?
Minimum epoch of this ChartData on the chart's X-Axis.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpdate(int leftEpoch, int rightEpoch) → void
Updates series visible data.
inherited
paint(Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void
Paints seriesPainter's data on the canvas.
inherited
recalculateMinMax() List<double>
Calculate min/max values in updated data
override
shouldRepaint(ChartData? previous) bool
Checks if this ChartData needs to repaint with the chart widget's new frame.
inherited
toString() String
A string representation of this object.
inherited
update(int leftEpoch, int rightEpoch) → void
Updates visible entries for this Series.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited