AccumulatorsActiveContract class

Used to hold the active active accumulators contract information.

Constructors

AccumulatorsActiveContract({required double? profit, required String? profitUnit, required int fractionalDigits})
Initializes AccumulatorsActiveContract.
const

Properties

fractionalDigits int
The number of decimal places to show the correct formatting of the profit value.
final
hashCode int
The hash code for this object.
no setterinherited
profit double?
Profit value of the current contract.
final
profitUnit String?
The profit unit label either currency or %, etc that will be shown next to profit value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited