isOverlay property
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to true.
Implementation
final bool isOverlay;
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to true.
final bool isOverlay;