AddingStateInfo class

Represents the information about progress of the tool being added to the interactive layer.

Constructors

AddingStateInfo(int currentStep, int totalSteps)
Creates an instance of AddingStateInfo.

Properties

currentStep int
The current step of the adding process of a DrawingAddingPreview.
final
hashCode int
The hash code for this object.
no setterinherited
isFinished bool
Indicates whether the adding process is finished.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalSteps int
The total number of steps required to complete the adding process.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited