AlligatorIndicatorConfig class

Bollinger Bands Indicator Config

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

AlligatorIndicatorConfig({int jawPeriod = 13, int teethPeriod = 8, int lipsPeriod = 5, int jawOffset = 8, int teethOffset = 5, int lipsOffset = 3, bool showLines = true, bool showFractal = false, LineStyle jawLineStyle = const LineStyle(color: Colors.blue), LineStyle teethLineStyle = const LineStyle(color: Colors.red), LineStyle lipsLineStyle = const LineStyle(color: Colors.green), bool showLastIndicator = false, String? title, int number = 0, int pipSize = 4})
Initializes
const
AlligatorIndicatorConfig.fromJson(Map<String, dynamic> json)
Initializes from JSON.
factory

Properties

configId String?
Drawing tool config id.
finalinherited
configSummary String
Indicator config summary
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isOverlay bool
Whether the add-on is an overlay on the main chart or displays on a separate chart. Default is set to true.
finalinherited
jawLineStyle LineStyle
Jaw line style.
final
jawOffset int
Shift to future in jaw series
final
jawPeriod int
Smoothing period for jaw series
final
lipsLineStyle LineStyle
Lips line style.
final
lipsOffset int
Shift to future in lips series
final
lipsPeriod int
Smoothing period for lips series
final
number int
The number of this add-on.
finalinherited
pipSize int
Number of digits after decimal point in price.
finalinherited
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortTitle String
Short display title.
no setterinherited
showFractal bool
show fractal indicator or not
final
showLastIndicator bool
Whether to show last indicator or not.
finalinherited
showLines bool
show alligator lins or not
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
teethLineStyle LineStyle
Teeth line style.
final
teethOffset int
Shift to future in teeth series
final
teethPeriod int
Smoothing period for teeth series
final
title String
The title of the indicator.
finalinherited

Methods

copyWith({int? jawPeriod, int? teethPeriod, int? lipsPeriod, int? jawOffset, int? teethOffset, int? lipsOffset, bool? showLines, bool? showFractal, LineStyle? jawLineStyle, LineStyle? teethLineStyle, LineStyle? lipsLineStyle, bool? showLastIndicator, String? title, int? pipSize, int? number}) AlligatorIndicatorConfig
Creates a copy of this instance with given parameters.
override
getItem(UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem
Creates indicator UI.
override
getSeries(IndicatorInput indicatorInput) Series
Creates indicator Series for the given indicatorInput.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialization to JSON. Serves as value in key-value storage.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

name → const String
Unique name for this indicator.