AnimationInfo class

A class that hold animation progress values.

Constructors

AnimationInfo({double currentTickPercent = 1, double blinkingPercent = 1, double stateChangePercent = 1})
Initializes
const

Properties

blinkingPercent → double
Animation percent of blinking dot in current tick.
final
currentTickPercent → double
Animation percent of current tick.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateChangePercent → double
Animation percent of InteractiveLayer state change.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited