longLine property

bool longLine
final

Barrier line start from screen edge or from the tick.

Will be ignored if the barrier has only an epoch or a value, and not both.

Implementation

final bool longLine;