CCIIndicatorConfig class

Commodity Channel Index Indicator configurations.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

CCIIndicatorConfig({int period = 20, OscillatorLinesConfig oscillatorLinesConfig = const OscillatorLinesConfig(overboughtValue: 100, oversoldValue: -100), bool showZones = true, LineStyle lineStyle = const LineStyle(color: Colors.white), int pipSize = 4, bool showLastIndicator = false, String? title, int number = 0})
Initializes.
const
CCIIndicatorConfig.fromJson(Map<String, dynamic> json)
Initializes from JSON.
factory

Properties

configId String?
Drawing tool config id.
finalinherited
configSummary String
Indicator config summary
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isOverlay bool
Whether the add-on is an overlay on the main chart or displays on a separate chart. Default is set to true.
finalinherited
lineStyle LineStyle
The CCI line style.
final
number int
The number of this add-on.
finalinherited
oscillatorLinesConfig OscillatorLinesConfig
The config of overbought/sold.
final
period int
The period to calculate the average gain and loss.
final
pipSize int
Number of digits after decimal point in price.
finalinherited
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortTitle String
Short display title.
no setterinherited
showLastIndicator bool
Whether to show last indicator or not.
finalinherited
showZones bool
Whether to paint overbought/sold zones fill.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
The title of the indicator.
finalinherited

Methods

copyWith({int? period, OscillatorLinesConfig? oscillatorLinesConfig, LineStyle? lineStyle, bool? showZones, int? pipSize, bool? showLastIndicator, String? title, int? number}) CCIIndicatorConfig
Creates a copy of this instance with given parameters.
override
getItem(UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem
Creates indicator UI.
override
getSeries(IndicatorInput indicatorInput) Series
Creates indicator Series for the given indicatorInput.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialization to JSON. Serves as value in key-value storage.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

name → const String
Unique name for this indicator.