CandleIndicator class

Indicator for showing the candle current value and remaining time (optional)

Inheritance

Constructors

CandleIndicator(Candle candle, {required int granularity, required DateTime serverTime, bool showTimer = false, String? id, HorizontalBarrierStyle style = const HorizontalBarrierStyle(), HorizontalBarrierVisibility visibility = HorizontalBarrierVisibility.keepBarrierLabelVisible})
Initializes a candle indicator.

Properties

annotationObject ↔ BarrierObject
Annotation Object.
getter/setter pairinherited
axisGroup → String?
Which axis this series scales against.
finalinherited
candle → Candle
The given candle.
final
epoch → int?
Epoch of the vertical barrier.
finalinherited
granularity → int
Average ms difference between two consecutive ticks.
final
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
The ID of this ChartData.
getter/setter pairinherited
isOnRange ↔ bool
Is this ChartAnnotation on the chart's epoch range.
getter/setter pairinherited
longLine → bool
Barrier line start from screen edge or from the tick.
finalinherited
maxValue → double
Max quote in a frame.
no setterinherited
maxValueInFrame ↔ double?
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
minValue → double
Min quote in a frame.
no setterinherited
minValueInFrame ↔ double?
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
previousObject ↔ BarrierObject?
Previous annotation object.
getter/setter pairinherited
quote → double?
The value that this barrier points to.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesPainter ↔ SeriesPainter<Series>?
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
serverTime → DateTime
The current time of the server.
final
showTimer → bool
Wether to show the candle close time timer or not.
final
style → ChartPaintingStyle?
The painting style of this Series.
finalinherited
timerDuration ↔ Duration?
The time duration left on the timer to show.
getter/setter pair
title → String?
Title of the barrier.
finalinherited
visibility → HorizontalBarrierVisibility
Barrier visibility behavior.
finalinherited

Methods

createObject() → BarrierObject
Prepares the annotationObject of this ChartAnnotation.
inherited
createPainter() → SeriesPainter<Series>
Is called whenever series is created to create its seriesPainter as well.
override
didUpdate(ChartData? oldData) → bool
Will be called by the chart when it was updated.
override
getMaxEpoch() → int?
Maximum epoch of this ChartData on the chart's X-Axis.
inherited
getMinEpoch() → int?
Minimum epoch of this ChartData on the chart's X-Axis.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(Offset localPosition) → bool
Called when this series' pane receives a tap at localPosition, in the same coordinate space as paint's size/canvas. Override to make a drawn region (e.g. a label) interactive. Returns true if the tap was handled by this series.
inherited
onUpdate(int leftEpoch, int rightEpoch) → void
Updates series visible data.
inherited
paint(Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void
Paints seriesPainter's data on the canvas.
inherited
recalculateMinMax() → List<double>
Calculate min/max values in updated data
inherited
shouldRepaint(ChartData? previous) → bool
Checks if this ChartData needs to repaint with the chart widget's new frame.
inherited
toString() → String
A string representation of this object.
inherited
update(int leftEpoch, int rightEpoch) → void
Updates visible entries for this Series.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited