neutralColor property
Neutral color for candles in which the price remains same or The vertical line inside candle which represents high/low.
Implementation
final Color neutralColor;
Neutral color for candles in which the price remains same or The vertical line inside candle which represents high/low.
final Color neutralColor;