snapMarkersToIntervals property

bool snapMarkersToIntervals
final

Whether markers' x-positions should snap to interval buckets (e.g., candle).

When true, marker epochs are snapped to the current granularity bucket for rendering, aligning markers to candle centerlines on chart.

Implementation

final bool snapMarkersToIntervals;