ChartData class abstract

Any data that the chart takes and makes it paint its self on the chart's canvas including Line, CandleStick data, Markers, barriers etc..

Implementers

Constructors

ChartData()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The ID of this ChartData.
getter/setter pair
maxValue double
The maximum value this ChartData has at the current X-Axis epoch range after update is called.
no setter
minValue double
The minimum value this ChartData has at the current X-Axis epoch range after update is called.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didUpdate(ChartData? oldData) bool
Will be called by the chart when it was updated.
getMaxEpoch() int?
Maximum epoch of this ChartData on the chart's X-Axis.
getMinEpoch() int?
Minimum epoch of this ChartData on the chart's X-Axis.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void
Paints this ChartData on the given canvas.
shouldRepaint(ChartData? oldData) bool
Checks if this ChartData needs to repaint with the chart widget's new frame.
toString() String
A string representation of this object.
inherited
update(int leftEpoch, int rightEpoch) → void
Updates this ChartData after the chart's epoch boundaries changes.

Operators

operator ==(Object other) bool
The equality operator.
inherited