didUpdate abstract method

bool didUpdate(
  1. ChartData? oldData
)

Will be called by the chart when it was updated.

Returns true if this chart data has changed with the chart widget update.

Implementation

bool didUpdate(ChartData? oldData);