paint abstract method

void paint(
  1. Canvas canvas,
  2. Size size,
  3. EpochToX epochToX,
  4. QuoteToY quoteToY,
  5. AnimationInfo animationInfo,
  6. ChartConfig chartConfig,
  7. ChartTheme theme,
  8. ChartScaleModel chartScaleModel,
)

Paints this ChartData on the given canvas.

Size is the size of the canvas.

epochToX and quoteToY are conversion functions in the chart's coordinate system. They respectively convert epoch to canvas X and quote to canvas Y.

animationInfo Contains animations progress values in this frame of painting.

ChartConfig is the chart's config which consist of

  • pipSize Number of decimal digits ChartData must use when showing their prices.
  • granularity Duration of 1 candle in ms (for ticks: average ms difference between ticks).

theme Chart's theme

Implementation

void paint(
  Canvas canvas,
  Size size,
  EpochToX epochToX,
  QuoteToY quoteToY,
  AnimationInfo animationInfo,
  ChartConfig chartConfig,
  ChartTheme theme,
  ChartScaleModel chartScaleModel,
);