ChartTheme class abstract

An interface for the Chart's theme.

Any app which wants to define the chart's theme should pass an implementation of this interface.

Implementers

Constructors

ChartTheme()

Properties

areaGradientEnd Color
no setter
areaGradientStart Color
no setter
areaLineColor Color
no setter
areaLineThickness double
no setter
backgroundColor Color
no setter
barStyle → BarStyle
The painting styles of histogram bar.
no setter
base01Color Color
This is a legacy method to get the legacy base01 color. It is used for backward compatibility with older versions of the chart. It should not be used in new code, as it'll be removed soon.
no setter
base03Color Color
This is a legacy method to get the legacy base03 color. It is used for backward compatibility with older versions of the chart. It should not be used in new code, as it'll be removed soon.
no setter
base04Color Color
This is a legacy method to get the legacy base04 color. It is used for backward compatibility with older versions of the chart. It should not be used in new code, as it'll be removed soon.
no setter
base05Color Color
This is a legacy method to get the legacy base05 color. It is used for backward compatibility with older versions of the chart. It should not be used in new code, as it'll be removed soon.
no setter
base07Color Color
This is a legacy method to get the legacy base07 color. It is used for backward compatibility with older versions of the chart. It should not be used in new code, as it'll be removed soon.
no setter
body1 TextStyle
no setter
body2 TextStyle
no setter
borderRadius04Chart double
no setter
borderRadius08Chart double
no setter
borderRadius16Chart double
no setter
borderRadius24Chart double
no setter
candleBearishBodyActive Color
no setter
candleBearishBodyDefault Color
no setter
candleBearishWickActive Color
no setter
candleBearishWickDefault Color
no setter
candleBullishBodyActive Color
no setter
candleBullishBodyDefault Color
no setter
candleBullishWickActive Color
no setter
candleBullishWickDefault Color
no setter
candleStyle CandleStyle
The painting styles of candlestick chart.
no setter
caption2 TextStyle
no setter
closedMarkerBorderColorGreen Color
no setter
closedMarkerBorderColorRed Color
no setter
closedMarkerSurfaceColorGreen Color
no setter
closedMarkerSurfaceColorRed Color
no setter
closedMarkerTextIconColorGreen Color
no setter
closedMarkerTextIconColorRed Color
no setter
crosshairAxisLabelStyle TextStyle
no setter
crosshairInformationBoxContainerGlassBackgroundBlur double
no setter
crosshairInformationBoxContainerGlassColor Color
no setter
crosshairInformationBoxContainerNormalColor Color
no setter
crosshairInformationBoxQuoteStyle TextStyle
no setter
crosshairInformationBoxTextDefault Color
no setter
crosshairInformationBoxTextLoss Color
no setter
crosshairInformationBoxTextProfit Color
no setter
crosshairInformationBoxTextStatic Color
no setter
crosshairInformationBoxTextSubtle Color
no setter
crosshairInformationBoxTimeLabelStyle TextStyle
no setter
crosshairInformationBoxTitleStyle TextStyle
no setter
crosshairLineDesktopColor Color
no setter
crosshairLineResponsiveLowerLineGradientEnd Color
no setter
crosshairLineResponsiveLowerLineGradientStart Color
no setter
crosshairLineResponsiveUpperLineGradientEnd Color
no setter
crosshairLineResponsiveUpperLineGradientStart Color
no setter
currentSpotContainerColor Color
no setter
currentSpotDotColor Color
no setter
currentSpotDotEffect Color
no setter
currentSpotLineColor Color
no setter
currentSpotStyle HorizontalBarrierStyle
The style of the current tick indicator.
no setter
currentSpotTextColor Color
no setter
currentSpotTextStyle TextStyle
no setter
entrySpotStyle → EntrySpotStyle
The painting styles of accumulators entry spot.
no setter
floatingMenuContainerGlassColor Color
no setter
floatingMenuDragIconColor Color
no setter
fontFamily String
no setter
gridLineColor Color
no setter
gridStyle GridStyle
no setter
gridTextColor Color
no setter
gridTextStyle TextStyle
no setter
hashCode int
The hash code for this object.
no setterinherited
horizontalBarrierStyle HorizontalBarrierStyle
The painting styles horizontal barriers.
no setter
lineStyle LineStyle
The painting styles of line chart.
no setter
lineThicknessDropdownButtonTextColor Color
no setter
lineThicknessDropdownButtonTextStyle TextStyle
no setter
lineThicknessDropdownItemSelectedBackgroundColor Color
no setter
lineThicknessDropdownItemSelectedLineColor Color
no setter
lineThicknessDropdownItemSelectedTextColor Color
no setter
lineThicknessDropdownItemTextStyle TextStyle
no setter
lineThicknessDropdownItemUnselectedLineColor Color
no setter
lineThicknessDropdownItemUnselectedTextColor Color
no setter
margin04Chart double
no setter
margin08Chart double
no setter
margin12Chart double
no setter
margin16Chart double
no setter
margin24Chart double
no setter
margin32Chart double
no setter
markerPaletteBorderColor Color
no setter
markerPaletteTextIconColor Color
no setter
markerStyle MarkerStyle
The painting styles of markers.
no setter
overLine TextStyle
no setter
profitAndLossLabelTextStyle TextStyle
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subheading TextStyle
no setter
title TextStyle
no setter
toolbarColorPaletteIconBlue Color
no setter
toolbarColorPaletteIconBlueBerry Color
no setter
toolbarColorPaletteIconBorderColor Color
no setter
toolbarColorPaletteIconGrape Color
no setter
toolbarColorPaletteIconGreen Color
no setter
toolbarColorPaletteIconMagenta Color
no setter
toolbarColorPaletteIconMustard Color
no setter
toolbarColorPaletteIconRed Color
Toolbar color palette colors for the color picker grid
no setter
toolbarColorPaletteIconSapphire Color
no setter
toolbarColorPaletteIconSeaWater Color
no setter
toolbarColorPaletteIconSelectedBorderColor Color
no setter
toolbarColorPaletteIconYellow Color
no setter
verticalBarrierStyle VerticalBarrierStyle
The painting styles vertical barriers.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textStyle({required TextStyle textStyle, Color? color}) TextStyle
The style of text is generated by calling this function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited