base03Color property

Color get base03Color

This is a legacy method to get the legacy base03 color. It is used for backward compatibility with older versions of the chart. It should not be used in new code, as it'll be removed soon.

Implementation

// TODO(Jim): Remove this method when an alternative is available.
Color get base03Color;