DataPainter<S extends DataSeries<Tick> > class
abstract
A class to paint common option of DataSeries data.
- Inheritance
-
- Object
- SeriesPainter<
S> - DataPainter
- Implementers
Constructors
-
DataPainter(DataSeries<
Tick> series) - Initializes series for sub-class.
Properties
- chartConfig ↔ ChartConfig
-
Chart's config.
getter/setter pairinherited
- chartScaleModel ↔ ChartScaleModel
-
Chart's scale model.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- series → S
-
The Series which this SeriesPainter belongs to.
finalinherited
- theme ↔ ChartTheme
-
Chart's theme.
getter/setter pairinherited
Methods
-
getEpochOf(
Tick tick, int index) → int -
Gets the real epoch value for the given
tick. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPaint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo}) → void -
Paints DataSeries.visibleEntries on the
canvas.override -
onPaintData(
Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo) → void - Paints DataSeries.visibleEntries.
-
paint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo, required ChartConfig chartConfig, required ChartTheme theme, required ChartScaleModel chartScaleModel}) → void -
Sets some variables and paints this SeriesPainter's data.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited