getMinEpoch method

  1. @override
int? getMinEpoch()
override

Minimum epoch of this ChartData on the chart's X-Axis.

The chart calls this on any of its ChartDatas and gets their minimum epoch then sets its X-Axis leftmost scroll limit based on them.

Implementation

@override
int? getMinEpoch() => input.isNotEmpty ? getEpochOf(input.first, 0) : null;