FractalChaosBandIndicatorConfig class

Fractal Chaos Band Indicator Config

Inheritance
Annotations
  • @JsonSerializable.new()
  • @ColorConverter.new()

Constructors

FractalChaosBandIndicatorConfig({LineStyle highLineStyle = const LineStyle(color: Colors.blue), LineStyle lowLineStyle = const LineStyle(color: Colors.blue), Color fillColor = Colors.white12, bool showChannelFill = false, bool showLastIndicator = false, String? title, int number = 0, int pipSize = 4})
Initializes
const
FractalChaosBandIndicatorConfig.fromJson(Map<String, dynamic> json)
Initializes from JSON.
factory

Properties

configId String?
Drawing tool config id.
finalinherited
configSummary String
Indicator config summary
no setterinherited
fillColor Color
Fill color.
final
hashCode int
The hash code for this object.
no setterinherited
highLineStyle LineStyle
Upper line style.
final
isOverlay bool
Whether the add-on is an overlay on the main chart or displays on a separate chart. Default is set to true.
finalinherited
lowLineStyle LineStyle
Lower line style.
final
number int
The number of this add-on.
finalinherited
pipSize int
Number of digits after decimal point in price.
finalinherited
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortTitle String
Short display title.
no setterinherited
showChannelFill bool
if it's true the channel between two lines will be filled
final
showLastIndicator bool
Whether to show last indicator or not.
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
The title of the indicator.
finalinherited

Methods

copyWith({LineStyle? highLineStyle, LineStyle? lowLineStyle, Color? fillColor, bool? showChannelFill, bool? showLastIndicator, String? title, int? number, int? pipSize}) FractalChaosBandIndicatorConfig
Creates a copy of this instance with given parameters.
override
getItem(UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem
Creates indicator UI.
override
getSeries(IndicatorInput indicatorInput) Series
Creates indicator Series for the given indicatorInput.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialization to JSON. Serves as value in key-value storage.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

name → const String
Unique name for this indicator.