HorizontalBarrierVisibility enum

Horizontal barrier visibility behavior and whether it contributes in defining the overall Y-Axis range of the chart.

Inheritance
Available extensions

Values

normal → const HorizontalBarrierVisibility

Won't force the chart to keep the barrier in its Y-Axis range, if it was out of range it will go off the screen.

keepBarrierLabelVisible → const HorizontalBarrierVisibility

Won't force the chart to keep the barrier in its Y-Axis range, if it was out of range, will show it on top/bottom edge with an arrow which indicates its value is beyond Y-Axis range.

forceToStayOnRange → const HorizontalBarrierVisibility

Will forces the chart to keep this barrier in its Y-Axis range.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HorizontalBarrierVisibility>
A constant List of the values in this enum, in order of their declaration.