IndicatorInput class

Indicator's input

Constructors

IndicatorInput(List<Tick> entries, int granularity)
Initializes

Properties

entries List<Tick>
Input entries.
final
granularity int
The granularity of this entries data.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createResult(int index, double value) → IndicatorResult
Creates IndicatorResult entry from given index and value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited