drawingContext property
DrawingContext
drawingContext
final
A callback to get the updated state of any drawing tool when calling it.
Implementation
final DrawingContext drawingContext;
A callback to get the updated state of any drawing tool when calling it.
final DrawingContext drawingContext;