InteractiveAddingToolState class

The state of the interactive layer when a tool is being added.

This class represents the state of the InteractiveLayer when a new drawing tool is being added to the chart. In this state, tapping on the chart will create a new drawing of the specified type.

After the drawing is created, the interactive layer transitions back to the InteractiveNormalState.

Inheritance
Mixed-in types
Implementers
Available extensions

Constructors

InteractiveAddingToolState(DrawingToolConfig addingTool, {required InteractiveLayerBehaviour interactiveLayerBehaviour})
Initializes the state with the interactive layer and the addingTool.

Properties

addingDrawingPreview DrawingAddingPreview<InteractableDrawing<DrawingToolConfig>>?
Getter to get the _drawingPreview instance.
no setter
addingStateInfo AddingStateInfo?
Getter to get the _addingStateInfo instance.
no setter
addingTool DrawingToolConfig
The tool being added.
final
epochFromX EpochFromX
Converts x coordinate (in pixels) to epoch timestamp.
no setterinherited
epochToX EpochToX
Converts epoch timestamp to x coordinate (in pixels).
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interactiveLayer → InteractiveLayerBase
The interactive layer that owns this state.
no setterinherited
interactiveLayerBehaviour InteractiveLayerBehaviour
The interactive layer.
finalinherited
previewDrawings List<DrawingV2>
Additional drawings of the state to be drawn on top of the main drawings.
no setteroverride
previewWidgets List<Widget>
Additional widgets to be rendered on top of the interactive layer.
no setterinherited
quoteFromY QuoteFromY
Converts y coordinate (in pixels) to quote value.
no setterinherited
quoteToY QuoteFromY
Converts quote value to y coordinate (in pixels).
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

anyDrawingHit(Offset hitOffset) InteractableDrawing<DrawingToolConfig>?

Available on InteractiveState, provided by the InteractiveStateExtension extension

Returns the drawing that was hit by the tap event. Returns null if no drawing was hit.
getToolState(DrawingV2 drawing) Set<DrawingToolState>
Returns the state of the drawing tool.
override
getToolZOrder(DrawingV2 drawing) → DrawingZOrder
Returns the z-order for the tool drawings.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHover(PointerHoverEvent event) bool
Handles hover event. Returns true if the hover is over a drawing tool, false otherwise.
override
onLongPress(Offset localPosition) bool
Handles long press event. Returns true if the long press was handled by a drawing tool, false otherwise.
inherited
onLongPressEnd() bool
Handles long press end event. Returns true if the long press end was handled by a drawing tool, false otherwise.
inherited
onPanEnd(DragEndDetails details) bool
Handles pan end event. Returns true if the pan end is affecting a drawing tool, false otherwise.
override
onPanStart(DragStartDetails details) bool
Handles pan start event. Returns true if the pan was started on a drawing tool, false otherwise.
override
onPanUpdate(DragUpdateDetails details) bool
Handles pan update event. Returns true if the pan update is affecting a drawing tool, false otherwise.
override
onTap(TapUpDetails details) bool
Handles tap event. Returns true if the tap was handled by a drawing tool, false otherwise.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited