InteractiveAddingToolStateMobile class

The mobile-specific implementation of the interactive adding tool state.

Inheritance
Available extensions

Constructors

InteractiveAddingToolStateMobile(DrawingToolConfig addingTool, {required InteractiveLayerBehaviour interactiveLayerBehaviour})
Adding tool state for mobile devices.

Properties

addingDrawingPreview DrawingAddingPreview<InteractableDrawing<DrawingToolConfig>>?
Getter to get the _drawingPreview instance.
no setterinherited
addingStateInfo AddingStateInfo?
Getter to get the _addingStateInfo instance.
no setterinherited
addingTool DrawingToolConfig
The tool being added.
finalinherited
epochFromX EpochFromX
Converts x coordinate (in pixels) to epoch timestamp.
no setterinherited
epochToX EpochToX
Converts epoch timestamp to x coordinate (in pixels).
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interactiveLayer → InteractiveLayerBase
The interactive layer that owns this state.
no setterinherited
interactiveLayerBehaviour InteractiveLayerBehaviour
The interactive layer.
finalinherited
previewDrawings List<DrawingV2>
Additional drawings of the state to be drawn on top of the main drawings.
no setterinherited
previewWidgets List<Widget>
Additional widgets to be rendered on top of the interactive layer.
no setterinherited
quoteFromY QuoteFromY
Converts y coordinate (in pixels) to quote value.
no setterinherited
quoteToY QuoteFromY
Converts quote value to y coordinate (in pixels).
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

anyDrawingHit(Offset hitOffset) InteractableDrawing<DrawingToolConfig>?

Available on InteractiveState, provided by the InteractiveStateExtension extension

Returns the drawing that was hit by the tap event. Returns null if no drawing was hit.
getToolState(DrawingV2 drawing) Set<DrawingToolState>
Returns the state of the drawing tool.
inherited
getToolZOrder(DrawingV2 drawing) → DrawingZOrder
Returns the z-order for the tool drawings.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onHover(PointerHoverEvent event) bool
Handles hover event. Returns true if the hover is over a drawing tool, false otherwise.
inherited
onLongPress(Offset localPosition) bool
Handles long press event. Returns true if the long press was handled by a drawing tool, false otherwise.
inherited
onLongPressEnd() bool
Handles long press end event. Returns true if the long press end was handled by a drawing tool, false otherwise.
inherited
onPanEnd(DragEndDetails details) bool
Handles pan end event. Returns true if the pan end is affecting a drawing tool, false otherwise.
inherited
onPanStart(DragStartDetails details) bool
Handles pan start event. Returns true if the pan was started on a drawing tool, false otherwise.
inherited
onPanUpdate(DragUpdateDetails details) bool
Handles pan update event. Returns true if the pan update is affecting a drawing tool, false otherwise.
inherited
onTap(TapUpDetails details) bool
Handles tap event. Returns true if the tap was handled by a drawing tool, false otherwise.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited