onUpdate property

VoidCallback onUpdate
getter/setter pair

The callback that is called when the interactive layer needs to be updated.

Note: This is not final to allow reassignment when the widget rebuilds.

Implementation

late VoidCallback onUpdate;