InteractiveLayerController constructor

InteractiveLayerController({
  1. Offset floatingMenuInitialPosition = Offset.zero,
})

Creates an instance of InteractiveLayerController.

floatingMenuInitialPosition is the initial position of the floating menu that appears when a drawing is selected. Once it appears on this initial position, it can be moved by the user and the internal floatingMenuPosition will be updated accordingly.

Implementation

InteractiveLayerController({Offset floatingMenuInitialPosition = Offset.zero})
  : floatingMenuPosition = floatingMenuInitialPosition;