epochToX property

EpochToX get epochToX

Converts epoch timestamp to x coordinate (in pixels).

This is a convenience getter that provides access to the coordinate conversion function from the interactive layer.

Implementation

EpochToX get epochToX => interactiveLayer.epochToX;