quoteFromY property

QuoteFromY get quoteFromY

Converts y coordinate (in pixels) to quote value.

This is a convenience getter that provides access to the coordinate conversion function from the interactive layer.

Implementation

QuoteFromY get quoteFromY => interactiveLayer.quoteFromY;