LegacyDarkThemeColors class

These colors suits the dark theme. They are used in the legacy chart and should be replaced with the new colours from DarkThemeColors

Constructors

LegacyDarkThemeColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accentGreen → const Color
accentRed → const Color
accentYellow → const Color
base01 → const Color
base02 → const Color
base03 → const Color
base04 → const Color
base05 → const Color
base06 → const Color
base07 → const Color
base08 → const Color
hover → const Color