LineStyle class

Defines the style of painting line data.

Annotations
  • @JsonSerializable.new()
  • @ColorConverter.new()

Constructors

LineStyle({Color color = const Color(0xFF85ACB0), double thickness = 1, bool hasArea = false, double markerRadius = 4, ({Color end, Color start}) areaGradientColors = (start: Color(0x29000000), end: Color(0x00000000))})
Initializes a style that defines the style of painting line data.
const
LineStyle.fromJson(Map<String, dynamic> json)
Initializes from JSON.
factory

Properties

areaGradientColors → ({Color end, Color start})
Area gradient colors.
final
color Color
Line color.
final
hasArea bool
Whether the line series has area or not.
final
hashCode int
The hash code for this object.
no setterinherited
markerRadius double
Marker radius.
final
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
thickness double
Line thickness.
final

Methods

copyWith({Color? color, double? thickness, bool? hasArea, double? markerRadius, ({Color end, Color start})? areaGradientColors}) LineStyle
Creates a copy of this object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Parses this instance of LineStyle into a Map.
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited