MAEnvIndicatorConfig class

Moving Average Envelope Indicator Config

Inheritance
Annotations
  • @JsonSerializable.new()
  • @ColorConverter.new()

Constructors

MAEnvIndicatorConfig({int period = 50, MovingAverageType movingAverageType = MovingAverageType.simple, String fieldType = 'close', double shift = 5, ShiftType shiftType = ShiftType.percent, LineStyle upperLineStyle = const LineStyle(color: Colors.green), LineStyle middleLineStyle = const LineStyle(color: Colors.blue), LineStyle lowerLineStyle = const LineStyle(color: Colors.red), Color fillColor = Colors.white12, bool showChannelFill = true, bool showLastIndicator = false, int number = 0})
Initializes
const
MAEnvIndicatorConfig.fromJson(Map<String, dynamic> json)
Initializes from JSON.
factory

Properties

configId String?
Drawing tool config id.
finalinherited
configSummary String
Indicator config summary
no setterinherited
fieldType String
Field type
finalinherited
fillColor Color
Fill color.
final
hashCode int
The hash code for this object.
no setterinherited
isOverlay bool
Whether the add-on is an overlay on the main chart or displays on a separate chart. Default is set to true.
finalinherited
lineStyle LineStyle
MA line style
finalinherited
lowerLineStyle LineStyle
Lower line style.
final
middleLineStyle LineStyle
Middle line style.
final
movingAverageType MovingAverageType
Moving Average type
finalinherited
number int
The number of this add-on.
finalinherited
offset int
The offset of this indicator.
finalinherited
period int
Moving Average period
finalinherited
pipSize int
Number of digits after decimal point in price.
finalinherited
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift double
Moving Average Envelope shift
final
shiftType → ShiftType
Moving Average Envelope shift type
final
shortTitle String
Short display title.
no setterinherited
showChannelFill bool
Whether the area between upper and lower channel is filled.
final
showLastIndicator bool
Whether to show last indicator or not.
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
title String
The title of the indicator.
no setterinherited
upperLineStyle LineStyle
Upper line style.
final

Methods

copyWith({int? period, MovingAverageType? movingAverageType, String? fieldType, double? shift, ShiftType? shiftType, LineStyle? upperLineStyle, LineStyle? middleLineStyle, LineStyle? lowerLineStyle, Color? fillColor, bool? showChannelFill, bool? showLastIndicator, int? number, int? pipSize, bool? isOverlay, int? offset, LineStyle? lineStyle, String? title}) MAEnvIndicatorConfig
Creates a copy of this instance with given parameters.
override
getItem(UpdateIndicator updateIndicator, VoidCallback deleteIndicator) IndicatorItem
Creates indicator UI.
override
getSeries(IndicatorInput indicatorInput) Series
Creates indicator Series for the given indicatorInput.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialization to JSON. Serves as value in key-value storage.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

name → const String
Unique name for this indicator.