MAEnvIndicatorItemState class

MAEnvIndicatorItem State class

Inheritance

Constructors

MAEnvIndicatorItemState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentOffset → int
Gets Indicator current period.
no setterinherited
field ↔ String?
Field type
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
indicatorsRepo ↔ Repository<IndicatorConfig>
Indicators repository
getter/setter pairinherited
lineStyle ↔ LineStyle?
MA line style
getter/setter pairinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
offset ↔ int?
MA period
getter/setter pairinherited
period ↔ int?
MA period
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shift ↔ double?
MA Env shift
getter/setter pair
shiftType ↔ ShiftType?
Field ShiftType
getter/setter pair
type ↔ MovingAverageType?
MA type
getter/setter pairinherited
widget → IndicatorItem
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
buildFieldTypeMenu() → Widget
Builds MA Field type menu
inherited
buildMATypeMenu() → Widget
Returns MA types dropdown menu
inherited
buildOffsetField() → Widget
Builds offset TextFiled
inherited
buildPeriodField() → Widget
Builds Period TextFiled
inherited
buildShiftField() → Widget
Builds Period TextFiled
buildShiftTypeMenu() → Widget
Returns shift types dropdown menu
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant IndicatorItem oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getCurrentField() → String
Gets Indicator current filed type.
inherited
getCurrentLineStyle() → LineStyle
Gets Indicator current line style.
override
getCurrentPeriod() → int
Gets Indicator current period.
inherited
getCurrentShift() → double
Gets Indicator current period.
getCurrentShiftType() → ShiftType
Gets Indicator current type.
getCurrentType() → MovingAverageType
Gets Indicator current type.
inherited
getIndicatorOptions() → Widget
Creates the menu options widget for this indicator.
override
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeIndicator() → void
Removes this indicator.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateIndicator() → void
Updates indicator based on its current config values.
inherited
updateIndicatorConfig() → MAEnvIndicatorConfig
Updates the current widget.config with the latest values set in menus options and returns the updated config.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited