MAIndicatorConfig class
Moving Average indicator config
- Inheritance
-
- Object
- AddOnConfig
- IndicatorConfig
- MAIndicatorConfig
- Implementers
- Annotations
-
- @JsonSerializable.new()
Constructors
- MAIndicatorConfig({int? period, MovingAverageType? movingAverageType, String? fieldType, LineStyle? lineStyle, int? offset, bool isOverlay = true, int pipSize = 4, bool showLastIndicator = false, String? title, int number = 0})
-
Initializes
const
-
MAIndicatorConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- configId → String?
-
Drawing tool config id.
finalinherited
- configSummary → String
-
Indicator config summary
no setteroverride
- fieldType → String
-
Field type
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - lineStyle → LineStyle
-
MA line style
final
- movingAverageType → MovingAverageType
-
Moving Average type
final
- number → int
-
The number of this add-on.
finalinherited
- offset → int
-
The offset of this indicator.
final
- period → int
-
Moving Average period
final
- pipSize → int
-
Number of digits after decimal point in price.
finalinherited
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortTitle → String
-
Short display title.
no setteroverride
- showLastIndicator → bool
-
Whether to show last indicator or not.
finalinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - title → String
-
The title of the indicator.
no setteroverride
Methods
-
copyWith(
{int? period, MovingAverageType? movingAverageType, String? fieldType, LineStyle? lineStyle, int? offset, bool? isOverlay, int? pipSize, bool? showLastIndicator, String? title, int? number}) → MAIndicatorConfig -
Creates a copy of this instance with given parameters.
override
-
getItem(
UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem -
Creates indicator UI.
override
-
getSeries(
IndicatorInput indicatorInput) → Series -
Creates indicator Series for the given
indicatorInput.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited