Marker class

Chart open position marker.

Inheritance
Implemented types
Implementers

Constructors

Marker({required int epoch, required double quote, required MarkerDirection direction, VoidCallback? onTap})
Creates a marker of given direction.
Marker.down({required int epoch, required double quote, VoidCallback? onTap})
Creates a down marker.
Marker.up({required int epoch, required double quote, VoidCallback? onTap})
Creates an up marker.

Properties

close → double
Close value (last value in OHLC period)
no setterinherited
direction → MarkerDirection
Direction in which marker is facing.
final
epoch → int
Epoch of the tick
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
high → double
High value (highest value in OHLC period)
no setterinherited
low → double
Low value (lowest value in OHLC period)
no setterinherited
onTap → VoidCallback?
Called when marker is tapped.
final
open → double
Open value (first value in OHLC period)
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
quote → double
Tick price
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tapArea ↔ Rect
Used to store marker tap area on the chart.
getter/setter pair

Methods

compareTo(covariant Marker other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited