MarkerStyle class

Defines the style of markers.

Constructors

MarkerStyle({Color upColor = const Color(0xFF00C390), Color downColor = const Color(0xFFDE0040), Color upColorProminent = const Color(0xFF00AE7A), Color downColorProminent = const Color(0xFFC40025), Color backgroundColor = const Color(0xFFFFFFFF), Color lineProfitColor = const Color(0xFF008832), Color lineLossColor = const Color(0xFFE6190E), Color lineDefaultColor = const Color(0xFFCED0D6), Color markerTextColor = const Color(0xFFFFFFFF), double radius = 12.0, TextStyle activeMarkerText = const TextStyle(color: Colors.black, fontSize: 12, fontWeight: FontWeight.w700), double textLeftPadding = 8.0, double textRightPadding = 16.0, EntryExitMarkerStyle entryMarkerStyle = const EntryExitMarkerStyle(), EntryExitMarkerStyle exitMarkerStyle = const EntryExitMarkerStyle(color: Color(0xFF00A79E), borderColor: Color(0xFFFFFFFF)), TextStyle markerLabelTextStyle = const TextStyle(color: Colors.white, fontSize: 12, fontWeight: FontWeight.w700), TextStyle markerPlainTextStyle = const TextStyle(color: Colors.white, fontSize: 12, fontWeight: FontWeight.w700, height: 1), TextStyle markerCounterPrimaryTextStyle = const TextStyle(color: Colors.white, fontSize: 20, fontWeight: FontWeight.w700), TextStyle markerCounterSecondaryTextStyle = const TextStyle(color: Colors.white, fontSize: 12, fontWeight: FontWeight.w400), IconData startTimeIcon = QuillIcons.stopwatch, IconData endTimeIcon = QuillIcons.flag_checkered})
Creates marker style.
const

Properties

activeMarkerText TextStyle
Active marker text style.
final
backgroundColor Color
Background Color of marker.
final
downColor Color
Color of marker pointing down.
final
downColorProminent Color
More prominent version of down marker and connector line color.
final
endTimeIcon IconData
Icon of the end time vertical line.
final
entryMarkerStyle EntryExitMarkerStyle
Style of an entry tick marker.
final
exitMarkerStyle EntryExitMarkerStyle
Style of an exit tick marker.
final
hashCode int
The hash code for this object.
no setterinherited
lineDefaultColor Color
Color of line for its default state.
final
lineLossColor Color
Color of line when the marker is loss.
final
lineProfitColor Color
Color of line when the marker is profit.
final
markerCounterPrimaryTextStyle TextStyle
Text style for the primary (current value) part of a counter marker text.
final
markerCounterSecondaryTextStyle TextStyle
Text style for the secondary (total value) part of a counter marker text.
final
markerLabelTextStyle TextStyle
Style of the marker label.
final
markerPlainTextStyle TextStyle
Text style for plain marker text displayed on the connector line.
final
markerTextColor Color
Color of the text displayed for a marker.
final
radius double
Radius of a single marker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimeIcon IconData
Icon of the start time vertical line.
final
textLeftPadding double
Active marker text left padding.
final
textRightPadding double
Active marker text right padding.
final
upColor Color
Color of marker pointing up.
final
upColorProminent Color
More prominent version of up marker and connector line color.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited