MarketSelector class

A widget which is used to select the market of the chart.

Inheritance

Constructors

MarketSelector({required List<Market> markets, Key? key, OnAssetClicked? onAssetClicked, Asset? selectedItem, List<Asset?>? favouriteAssets, ChartTheme? theme})
Initializes a widget which is used to select the market of the chart.
const

Properties

favouriteAssets → List<Asset?>?
Optional whenever it is null, it will be substituted with a list of assets that their Asset.isFavourite is true.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
markets → List<Market>
A list of markets which the user can select from.
final
onAssetClicked → OnAssetClicked?
It will be called when a symbol item Asset is tapped.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedItem → Asset?
The selected asset item which contains the details of the selected market.
final
theme → ChartTheme?
The theme of the chart which the market selector is being placed inside.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MarketSelector>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited