MarketSelectorButton class

A Button to open the market selector. The selected Asset should be passed as asset.

Inheritance

Constructors

MarketSelectorButton({required Asset asset, Key? key, Color backgroundColor = const Color.fromRGBO(21, 23, 23, 1), BorderRadius borderRadius = const BorderRadius.all(Radius.circular(4)), VoidCallback? onTap, TextStyle textStyle = const TextStyle(fontSize: 12, color: Colors.white), ChartTheme? theme})
Creates a Button to open the market selector. The selected Asset should be passed as asset.
const

Properties

asset Asset
The asset retrieved from the API.
final
backgroundColor Color
The color of the button.
final
borderRadius BorderRadius
The assigned radius of the button.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap VoidCallback?
Called when the market selector button is clicked.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle
The text style of the asset used inside the button.
final
theme ChartTheme?
Chart's theme.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

iconFadeDuration → const Duration
The duration of the fade animaiton of the button icon.