MinMaxIndices class

A model class to hold min/max indices of a list

Constructors

MinMaxIndices(int minIndex, int maxIndex)
Initializes
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxIndex → int
Max index.
final
minIndex → int
Min index.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited