OHLCTypeSeries class abstract

Super-class of series with OHLC data (CandleStick, OHLC, Hollow).

Inheritance
Implementers

Constructors

OHLCTypeSeries(List<Candle> entries, String id, {CandleStyle? style, HorizontalBarrierStyle? lastTickIndicatorStyle})
Initializes

Properties

axisGroup → String?
Which axis this series scales against.
finalinherited
entries ↔ List<Candle>?
The list of this class that will be painted on the canvas.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
The ID of this ChartData.
getter/setter pairinherited
input → List<Candle>
Series input list.
finalinherited
lastTickIndicatorStyle → HorizontalBarrierStyle?
Style of a last tick indicator. null if indicator is absent.
finalinherited
maxValue → double
Max quote in a frame.
no setterinherited
maxValueInFrame ↔ double?
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
minValue → double
Min quote in a frame.
no setterinherited
minValueInFrame ↔ double?
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
prevLastEntry ↔ IndexedEntry<Candle>?
A reference to the last element of the previous version of this DataSeries.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seriesPainter ↔ SeriesPainter<Series>?
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
style → ChartPaintingStyle?
The painting style of this Series.
finalinherited
visibleEntries → VisibleEntries<Candle>
Series visible entries
no setterinherited

Methods

createPainter() → SeriesPainter<Series>?
Is called whenever series is created to create its seriesPainter as well.
inherited
createVirtualTick(int epoch, double quote) → Candle
Creates a virtual tick for crosshair display when cursor is outside data range. Each series type should implement this to return the appropriate tick type.
inherited
didUpdate(ChartData? oldData) → bool
Will be called by the chart when it was updated.
inherited
fillEntriesFromInput(covariant DataSeries<Tick> oldSeries) → void
Fills the entries that are about to be painted based on input and oldSeries
inherited
getCrosshairDetailsBoxHeight() → double
Returns the height of the crosshair details box for this series type. Each series type should implement this to return the appropriate height.
inherited
getCrosshairDotPainter(ChartTheme theme) → CrosshairDotPainter
Returns a CrosshairDotPainter for painting a dot at the crosshair position. Each series type should implement this to return the appropriate dot painter.
inherited
getCrosshairHighlightPainter(Candle crosshairTick, double quoteToY(double), double xCenter, int granularity, double xFromEpoch(int), ChartTheme theme) → CrosshairHighlightPainter
Returns a CrosshairHighlightPainter for highlighting the element at the crosshair position. Each series type should implement this to return the appropriate highlight painter.
inherited
getCrossHairInfo(Candle crossHairTick, int pipSize, ChartTheme theme, CrosshairVariant crosshairVariant) → Widget
Each sub-class should implement and return appropriate cross-hair text based on its own requirements.
override
getCrossHairInfoLargeScreen({required Candle crossHairTick, required int pipSize, required ChartTheme theme}) → Widget
Creates a widget to display crosshair information for large screens.
getCrossHairInfoSmallScreen({required Candle crossHairTick, required int pipSize, required ChartTheme theme}) → Widget
Creates a widget to display crosshair information for small screens.
getEpochOf(Candle t, int index) → int
Gets the real epoch for the given t.
inherited
getMaxEpoch() → int?
Maximum epoch of this ChartData on the chart's X-Axis.
inherited
getMinEpoch() → int?
Minimum epoch of this ChartData on the chart's X-Axis.
inherited
getVisibleEntries(int startIndex, int endIndex) → VisibleEntries<Candle>
Creates visible entries based on startIndex and endIndex.
inherited
initialize() → void
Initializes entries from the input.
inherited
isOldDataAvailable(covariant DataSeries<Tick>? oldSeries) → bool
Checks whether the old data of the series is available to use
inherited
maxValueOf(Candle t) → double
Maximum value in t.
override
minValueOf(Candle t) → double
Minimum value in t.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(Offset localPosition) → bool
Called when this series' pane receives a tap at localPosition, in the same coordinate space as paint's size/canvas. Override to make a drawn region (e.g. a label) interactive. Returns true if the tap was handled by this series.
inherited
onUpdate(int leftEpoch, int rightEpoch) → void
Updates visible entries for this Series.
inherited
paint(Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void
Paints seriesPainter's data on the canvas.
inherited
recalculateMinMax() → List<double>
Gets min and max quotes after updating visibleEntries as an array with two elements min, max.
inherited
resetLastEntryAnimation() → void
Use this to reset last tick in entries animation by setting prevLastEntry to null.
inherited
shouldRepaint(ChartData? oldDelegate) → bool
Checks if this ChartData needs to repaint with the chart widget's new frame.
inherited
toString() → String
A string representation of this object.
inherited
update(int leftEpoch, int rightEpoch) → void
Updates visible entries for this Series.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited