OnEditAddOn typedef
OnEditAddOn =
dynamic Function(int index)
Called when the edit icon is clicked on an add-on.
Implementation
typedef OnEditAddOn = Function(int index);
Called when the edit icon is clicked on an add-on.
typedef OnEditAddOn = Function(int index);