OptionsMarkerIconPainter class

Icon painter for Options trade type

Inheritance

Constructors

OptionsMarkerIconPainter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintCircle(Canvas canvas, Offset center, Offset anchor, MarkerDirection direction, MarkerStyle style) → void
Paint circle
inherited
paintMarker(Canvas canvas, Offset center, Offset anchor, MarkerDirection direction, MarkerStyle style) → void
Paint marker
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited