OscillatorLinePainter class

A LinePainter for painting line with two main top and bottom horizontal lines. They can have more than 2 lines.

Inheritance

Constructors

OscillatorLinePainter(DataSeries<Tick> series, {double? topHorizontalLine, double? bottomHorizontalLine, LineStyle topHorizontalLinesStyle = const LineStyle(color: Colors.blueGrey), LineStyle bottomHorizontalLinesStyle = const LineStyle(color: Colors.blueGrey), HorizontalBarrierStyle labelStyle = const HorizontalBarrierStyle(textStyle: TextStyle(fontSize: 10, color: Color(0xFF0E0E0E))), LineStyle? secondaryHorizontalLinesStyle, List<double> secondaryHorizontalLines = const <double>[]})
Initializes an Oscillator line painter.

Properties

bottomHorizontalLinesStyle → LineStyle
Line style of the bottom horizontal line
final
chartConfig ↔ ChartConfig
Chart's config.
getter/setter pairinherited
chartScaleModel ↔ ChartScaleModel
Chart's scale model.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
labelStyle → HorizontalBarrierStyle
Line style of the bottom horizontal line
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → DataSeries<Tick>
The Series which this SeriesPainter belongs to.
finalinherited
theme ↔ ChartTheme
Chart's theme.
getter/setter pairinherited
topHorizontalLinesStyle → LineStyle
Line style of the top horizontal line
final

Methods

createPath(EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo) → DataLinePathInfo
Creates the path of the given series and returns it.
inherited
getEpochOf(Tick tick, int index) → int
Gets the real epoch value for the given tick.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPaint({required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo}) → void
Paints DataSeries.visibleEntries on the canvas.
inherited
onPaintData(Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo) → void
Paints DataSeries.visibleEntries.
override
paint({required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo, required ChartConfig chartConfig, required ChartTheme theme, required ChartScaleModel chartScaleModel}) → void
Sets some variables and paints this SeriesPainter's data.
inherited
paintLines(Canvas canvas, Path path, Paint linePaint) → void
Paints the line on the given canvas. We can add channel fill here in the subclasses.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

padding → const double
Padding between lines.
rightMargin → const double
Right margin.