minValueOf method

  1. @override
double minValueOf(
  1. Tick t
)
inherited

Minimum value in t.

sub-classes can decide what will be the min/max value of a T, this way a candlestick series can use (high, low) values as max and min and a line chart just use the close value and then a line chart can expand as much as it can in the vertical space since it just shows close values.

Implementation

@override
double minValueOf(Tick t) => t.quote;