RainbowIndicatorConfig class
Rainbow Indicator Config
- Inheritance
-
- Object
- AddOnConfig
- IndicatorConfig
- MAIndicatorConfig
- RainbowIndicatorConfig
- Annotations
-
- @JsonSerializable.new()
- @ColorConverter.new()
Constructors
-
RainbowIndicatorConfig({int period = 50, MovingAverageType movingAverageType = MovingAverageType.simple, String fieldType = 'close', int bandsCount = 10, List<
LineStyle> ? rainbowLineStyles, bool showLastIndicator = false, int number = 0}) -
Initializes
const
-
RainbowIndicatorConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- bandsCount → int
-
Rainbow Moving Averages bands count
final
- configId → String?
-
Drawing tool config id.
finalinherited
- configSummary → String
-
Indicator config summary
no setterinherited
- fieldType → String
-
Field type
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - lineStyle → LineStyle
-
MA line style
finalinherited
- movingAverageType → MovingAverageType
-
Moving Average type
finalinherited
- number → int
-
The number of this add-on.
finalinherited
- offset → int
-
The offset of this indicator.
finalinherited
- period → int
-
Moving Average period
finalinherited
- pipSize → int
-
Number of digits after decimal point in price.
finalinherited
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
-
rainbowLineStyles
→ List<
LineStyle> ? -
List of line styles for the different bands in the RainbowSeries.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortTitle → String
-
Short display title.
no setterinherited
- showLastIndicator → bool
-
Whether to show last indicator or not.
finalinherited
- showQuoteGrid → bool
-
Whether to show the y-axis quote grid (lines + labels) for this
indicator's pane.
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - title → String
-
The title of the indicator.
no setterinherited
Methods
-
copyWith(
{int? period, MovingAverageType? movingAverageType, String? fieldType, LineStyle? lineStyle, List< LineStyle> ? rainbowLineStyles, int? offset, bool? isOverlay, int? pipSize, bool? showLastIndicator, String? title, int? number, int? bandsCount}) → RainbowIndicatorConfig -
Creates a copy of this instance with given parameters.
override
-
getItem(
UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem -
Creates indicator UI.
override
-
getSeries(
IndicatorInput indicatorInput) → Series -
Creates indicator Series for the given
indicatorInput.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited