RectangleDrawingToolConfig class
Rectangle drawing tool configurations.
- Inheritance
-
- Object
- AddOnConfig
- DrawingToolConfig
- RectangleDrawingToolConfig
- Annotations
-
- @JsonSerializable.new()
Constructors
-
RectangleDrawingToolConfig({String? configId, DrawingData? drawingData, List<
EdgePoint> edgePoints = const <EdgePoint>[], LineStyle fillStyle = const LineStyle(thickness: 0.9, color: Colors.blue), LineStyle lineStyle = const LineStyle(thickness: 0.9, color: Colors.white), DrawingPatterns pattern = DrawingPatterns.solid, int number = 0}) -
Initializes
const
-
RectangleDrawingToolConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- configId → String?
-
Drawing tool config id.
finalinherited
- drawingData → DrawingData?
-
Drawing tool data.
finalinherited
-
edgePoints
→ List<
EdgePoint> -
Drawing tool edge points.
finalinherited
- fillStyle → LineStyle
-
Drawing tool fill style
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - lineStyle → LineStyle
-
Drawing tool line style
final
- number → int
-
The number of this add-on.
finalinherited
- pattern → DrawingPatterns
-
Drawing tool line pattern: 'solid', 'dotted', 'dashed'
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
copyWith(
{String? configId, DrawingData? drawingData, LineStyle? lineStyle, LineStyle? fillStyle, DrawingPatterns? pattern, List< EdgePoint> ? edgePoints, bool? enableLabel, int? number}) → RectangleDrawingToolConfig -
Creates a copy of this object.
override
-
getInteractableDrawing(
DrawingContext drawingContext, GetDrawingState getDrawingState) → InteractableDrawing< DrawingToolConfig> -
Returns back the InteractableDrawing instance of this drawing tool.
inherited
-
getItem(
UpdateDrawingTool updateDrawingTool, VoidCallback deleteDrawingTool) → DrawingToolItem -
Creates drawing tool.
override
-
getLabelPainter(
{required Point startPoint, required Point endPoint}) → DrawingToolLabelPainter? -
Create label painter for the drawing tool.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited