Repository<T> class abstract

Holds indicators/drawing tools that were added to the Chart during runtime.

Inheritance
Implementers
Available extensions

Constructors

Repository()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
items List<T>
Retrieves the list of items in a repository.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(T config) → void
To adds a new indicator or drawing tool.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
Clears all indicator and drawing tools
dispose() → void
Discards any resources used by the object.
inherited
editAt(int index) → void
Edits an existing indicator or drawing tool at the specified index. This method allows you to modify the settings and properties of the indicator or tool without changing its position in the list.
getHiddenStatus(int index) bool
Retrieves the hidden status of an indicator or drawing tool.
getNumberForNewAddOn(AddOnConfig addOn) int

Available on Repository<AddOnConfig>, provided by the AddOnsRepositoryConfigExtension extension

Gets the next number for a new indicator or drawing tool.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(T config) → void
Removes a specific indicator or drawing tool from the repository.
removeAt(int index) → void
Removes indicator or drawing tool at index.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
swap(int index1, int index2) → void
Swaps two elements of a list.
toString() String
A string representation of this object.
inherited
update() → void
Triggers an update to the repository to update its listeners.
updateAt(int index, T config) → void
Updates an existing indicator or drawing tool at the specified index with new configuration settings. This method allows you to modify the indicator or tool's properties while preserving its position in the list.
updateHiddenStatus({required int index, required bool hidden}) → void
Updates the hidden status of an indicator or drawing tool.

Operators

operator ==(Object other) bool
The equality operator.
inherited