SubMarket class

A class to keep a sub-market's information.

Constructors

SubMarket({required String name, required List<Asset?> assets, String? displayName})
Creates a class to keep a sub-market's information.

Properties

assets → List<Asset?>
The list of assets given from api with the information of each sub-market.
final
displayName → String
The displaying Name of the sub-market.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the sub-market.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

containsAssetWithText(String text) → bool
Returns true if any asset under this sub-market contains the text.
containsText(String text) → bool
Checks if the displayName contains the given text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited