Tick class

Basic data entry.

Implementers
Annotations

Constructors

Tick({required int epoch, required double quote})
Initializes
const

Properties

close double
Close value (last value in OHLC period)
no setter
epoch int
Epoch of the tick
final
hashCode int
The hash code for this object.
no setterinherited
high double
High value (highest value in OHLC period)
no setter
low double
Low value (lowest value in OHLC period)
no setter
open double
Open value (first value in OHLC period)
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
quote double
Tick price
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited