extendLeft property
Whether level lines are pinned to the chart's left edge instead of starting where they cross the (possibly extrapolated) diagonal anchor line.
Implementation
final bool extendLeft;
Whether level lines are pinned to the chart's left edge instead of starting where they cross the (possibly extrapolated) diagonal anchor line.
final bool extendLeft;