drawStyledPoint method

void drawStyledPoint(
  1. EdgePoint point,
  2. EpochToX epochToX,
  3. QuoteToY quoteToY,
  4. Canvas canvas,
  5. DrawingPaintStyle paintStyle,
  6. LineStyle lineStyle, {
  7. double radius = pointRadius,
})
inherited

Draws a trend line point with consistent styling across platforms.

This method provides a standardized way to draw trend line endpoints using the shared pointRadius constant. It converts the EdgePoint to screen coordinates and renders a styled circle.

Parameters:

  • point: The chart coordinate point to draw
  • epochToX: Function to convert epoch to screen X coordinate
  • quoteToY: Function to convert quote to screen Y coordinate
  • canvas: The canvas to draw on
  • paintStyle: Drawing paint configuration
  • lineStyle: Line styling configuration
  • radius: Optional custom radius (defaults to pointRadius)

Implementation

void drawStyledPoint(
  EdgePoint point,
  EpochToX epochToX,
  QuoteToY quoteToY,
  Canvas canvas,
  DrawingPaintStyle paintStyle,
  LineStyle lineStyle, {
  double radius = pointRadius,
}) {
  drawPoint(
    point,
    epochToX,
    quoteToY,
    canvas,
    paintStyle,
    lineStyle,
    radius: radius,
  );
}