paintOverYAxis method

  1. @override
void paintOverYAxis(
  1. Canvas canvas,
  2. Size size,
  3. EpochToX epochToX,
  4. QuoteToY quoteToY,
  5. EpochFromX? epochFromX,
  6. QuoteFromY? quoteFromY,
  7. AnimationInfo animationInfo,
  8. ChartConfig chartConfig,
  9. ChartTheme chartTheme,
  10. GetDrawingState getDrawingState,
)
override

Paints the drawing tool chart but over the Y-axis.

This is useful for the drawing wants to paint something that should be visible over the Y-axis, like a horizontal line or a label.

Implementation

@override
void paintOverYAxis(
  Canvas canvas,
  Size size,
  EpochToX epochToX,
  QuoteToY quoteToY,
  EpochFromX? epochFromX,
  QuoteFromY? quoteFromY,
  AnimationInfo animationInfo,
  ChartConfig chartConfig,
  ChartTheme chartTheme,
  GetDrawingState getDrawingState,
) {
  if (_hoverPosition != null && epochFromX != null && quoteFromY != null) {
    drawPointGuidesAndLabels(
      canvas,
      size,
      _hoverPosition!,
      epochToX,
      quoteToY,
      epochFromX,
      quoteFromY,
      chartConfig,
      chartTheme,
      showGuides: false,
    );
  }
}