VerticalBarrierObject class

Vertical barrier object.

Inheritance

Constructors

VerticalBarrierObject(int epoch, {double? quote})
Initializes a vertical barrier object.
const

Properties

bottomValue double?
bottomValue
finalinherited
epoch int
Epoch of the vertical barrier.
final
hashCode int
The hash code for this object.
no setterinherited
leftEpoch int?
leftEpoch
finalinherited
quote double?
Barrier's value.
finalinherited
rightEpoch int?
rightEpoch
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topValue double?
topValue
finalinherited

Methods

isOnEpochRange(int leftBoundEpoch, int rightBoundEpoch) bool
Whether this chart object is in chart horizontal visible area.
inherited
isOnValueRange(double bottomBoundValue, double topBoundValue) bool
Whether this chart object is in chart horizontal visible area.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant ChartObject other) bool
The equality operator.
inherited