VerticalBarrierStyle class

Vertical barrier style.

Inheritance

Constructors

VerticalBarrierStyle({Color color = Colors.grey, Color titleBackgroundColor = Colors.transparent, bool isDashed = true, VerticalBarrierLabelPosition labelPosition = VerticalBarrierLabelPosition.auto, TextStyle textStyle = const TextStyle(fontSize: 10, height: 1.3, fontWeight: FontWeight.normal, color: Colors.white, fontFeatures: <FontFeature>[FontFeature.tabularFigures()])})
Initializes a vertical barrier style.
const

Properties

color → Color
Color of the barrier.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isDashed → bool
Whether barrier's line should be dashed.
finalinherited
labelPosition → VerticalBarrierLabelPosition
Label position.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
Style of the title and value.
finalinherited
titleBackgroundColor → Color
Title label background color.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited