interactiveLayerBehaviour property

InteractiveLayerBehaviour? interactiveLayerBehaviour
final

Defines the behaviour that interactive layer should have.

Interactive layer is the layer on top of the chart responsible for handling components that user can interact with them. such as cross-hair, drawing tools, etc.

If not set it will be set internally to InteractiveLayerDesktopBehaviour on web and InteractiveLayerMobileBehaviour on mobile or other platforms.

Implementation

final InteractiveLayerBehaviour? interactiveLayerBehaviour;