isLive property

bool isLive
final

Whether the chart should be showing live data or not. In case of being true the chart will keep auto-scrolling when its visible area is on the newest ticks/candles.

Implementation

final bool isLive;