magnetEnabled property
Whether new drawing tool points snap to the nearest candle's time bucket instead of the exact cursor position ("magnet" mode).
Implementation
final bool magnetEnabled;
Whether new drawing tool points snap to the nearest candle's time bucket instead of the exact cursor position ("magnet" mode).
final bool magnetEnabled;