maxIntervalWidth property
Specifies the maximum interval width that is used for calculating the maximum msPerPx.
Implementation
final double? maxIntervalWidth;
Specifies the maximum interval width that is used for calculating the maximum msPerPx.
final double? maxIntervalWidth;