minIntervalWidth property
Specifies the minimum interval width that is used for calculating the maximum msPerPx.
Implementation
final double? minIntervalWidth;
Specifies the minimum interval width that is used for calculating the maximum msPerPx.
final double? minIntervalWidth;