ChartLocalization class

Constructors

ChartLocalization()

Properties

hashCode int
The hash code for this object.
no setterinherited
labelBandsCount String
Bands Count
no setter
labelBaseLinePeriod String
Base Line Period
no setter
labelChannelFill String
Channel Fill
no setter
labelColor String
Color
no setter
labelConversionLinePeriod String
Conversion Line Period
no setter
labelDistance String
Distance
no setter
labelDoubleSmoothingPeriod String
Double Smoothing Period
no setter
labelFastMAPeriod String
Fast MA Period
no setter
labelField String
Field
no setter
labelFillColor String
Fill Color
no setter
labelHighPeriod String
High Period
no setter
labelHistogram String
Histogram
no setter
labelIsSmooth String
Is Smooth
no setter
labelJawOffset String
Jaw Offset
no setter
labelJawPeriod String
Jaw Period
no setter
labelLaggingSpanOffset String
Lagging Span Offset
no setter
labelLipsOffset String
Lips Offset
no setter
labelLipsPeriod String
Lips Period
no setter
labelLowPeriod String
Low Period
no setter
labelMaxAF String
Max AF
no setter
labelMinAF String
Min AF
no setter
labelOffset String
Offset
no setter
labelOverBoughtPrice String
Over Bought Price
no setter
labelOverSoldPrice String
Over Sold Price
no setter
labelPeriod String
Period
no setter
labelSearchAssets String
Search assets
no setter
labelSeries String
Series
no setter
labelShading String
Shading
no setter
labelShift String
Shift
no setter
labelShiftType String
Shift Type
no setter
labelShowFractals String
Show Fractals
no setter
labelShowLines String
Show Lines
no setter
labelShowZones String
Show Zones
no setter
labelSignalPeriod String
Signal Period
no setter
labelSlowMAPeriod String
Slow MA Period
no setter
labelSmoothingPeriod String
Smoothing Period
no setter
labelSpanBPeriod String
Leading Span B Period
no setter
labelStandardDeviation String
Standard Deviation
no setter
labelTeethOffset String
Teeth Offset
no setter
labelTeethPeriod String
Teeth Period
no setter
labelType String
Type
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectDrawingTool String
Select drawing tool
no setter
warnCheckAssetSearchingText String
Try checking your spelling or use a different term
no setter
warnFailedLoadingDrawingTools String
Failed to load drawing tools.
no setter
warnFailedLoadingIndicators String
Failed to load indicators.
no setter

Methods

informNoResult(Object text) String
No results for "{text}"
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current ChartLocalization
no setter

Constants

delegate → const AppLocalizationDelegate