ADXIndicatorConfig class
adx Indicator Config
- Inheritance
-
- Object
- AddOnConfig
- IndicatorConfig
- ADXIndicatorConfig
- Annotations
-
- @JsonSerializable.new()
Constructors
- ADXIndicatorConfig({int period = 14, int smoothingPeriod = 14, bool showSeries = true, bool showChannelFill = false, bool showHistogram = false, bool showShading = false, LineStyle lineStyle = const LineStyle(color: Colors.white), LineStyle positiveLineStyle = const LineStyle(color: Colors.green), LineStyle negativeLineStyle = const LineStyle(color: Colors.red), BarStyle barStyle = const BarStyle(), int pipSize = 4, bool showLastIndicator = false, String? title, int number = 0})
-
Initializes
const
-
ADXIndicatorConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- barStyle → BarStyle
-
Histogram bar style
final
- configId → String?
-
Drawing tool config id.
finalinherited
- configSummary → String
-
Indicator config summary
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - lineStyle → LineStyle
-
Line style.
final
- negativeLineStyle → LineStyle
-
Negative line style.
final
- number → int
-
The number of this add-on.
finalinherited
- period → int
-
The period value for the ADX series.
final
- pipSize → int
-
Number of digits after decimal point in price.
finalinherited
- positiveLineStyle → LineStyle
-
Positive line style.
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortTitle → String
-
Short display title.
no setterinherited
- showChannelFill → bool
-
Whether to add channel fill between the Positive and Negative DI
Indicator.
final
- showHistogram → bool
-
Whether to show the histogram Series or not.
final
- showLastIndicator → bool
-
Whether to show last indicator or not.
finalinherited
- showSeries → bool
-
Wether to show the Series or not.
final
- showShading → bool
-
Whether to show the shading or not.
final
- smoothingPeriod → int
-
The period value for smoothing the ADX series.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - title → String
-
The title of the indicator.
finalinherited
Methods
-
copyWith(
{int? period, int? smoothingPeriod, bool? showChannelFill, bool? showHistogram, bool? showShading, bool? showSeries, LineStyle? lineStyle, LineStyle? positiveLineStyle, LineStyle? negativeLineStyle, BarStyle? barStyle, int? pipSize, bool? showLastIndicator, String? title, int? number}) → ADXIndicatorConfig -
Creates a copy of this instance with given parameters.
override
-
getItem(
UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem -
Creates indicator UI.
override
-
getSeries(
IndicatorInput indicatorInput) → Series -
Creates indicator Series for the given
indicatorInput.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited