AddOnConfig class abstract
Config for add-ons such as indicators and drawing tools
- Implementers
Constructors
- AddOnConfig({bool isOverlay = true, int number = 0, String? configId})
-
Initializes AddOnConfig.
const
Properties
- configId → String?
-
Drawing tool config id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.final - number → int
-
The number of this add-on.
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialization to JSON. Serves as value in key-value storage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited