AlligatorSeries class

A series which shows Alligator Series data calculated from 'entries'.

Inheritance

Constructors

AlligatorSeries(IndicatorInput indicatorInput, {required AlligatorOptions alligatorOptions, String? id})
Initializes a series which shows shows Alligator data calculated from indicatorInput.

Properties

alligatorOptions ↔ AlligatorOptions
Alligator options
getter/setter pair
axisGroup String?
Which axis this series scales against.
finalinherited
bearishSeries SingleIndicatorSeries?
Bearish Series
getter/setter pair
bullishSeries SingleIndicatorSeries?
Bullish Series
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
The ID of this ChartData.
getter/setter pairinherited
jawSeries SingleIndicatorSeries?
Jaw series
getter/setter pair
lipsSeries SingleIndicatorSeries?
Lips series
getter/setter pair
maxValue double
Max quote in a frame.
no setterinherited
maxValueInFrame double?
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
minValue double
Min quote in a frame.
no setterinherited
minValueInFrame double?
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesPainter SeriesPainter<Series>?
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
style → ChartPaintingStyle?
The painting style of this Series.
finalinherited
teethSeries SingleIndicatorSeries?
Teeth series
getter/setter pair

Methods

createPainter() SeriesPainter<Series>?
Is called whenever series is created to create its seriesPainter as well.
override
didUpdate(ChartData? oldData) bool
Will be called by the chart when it was updated.
override
getMaxEpoch() int?
Maximum epoch of this ChartData on the chart's X-Axis.
override
getMinEpoch() int?
Minimum epoch of this ChartData on the chart's X-Axis.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(Offset localPosition) bool
Called when this series' pane receives a tap at localPosition, in the same coordinate space as paint's size/canvas. Override to make a drawn region (e.g. a label) interactive. Returns true if the tap was handled by this series.
inherited
onUpdate(int leftEpoch, int rightEpoch) → void
Updates series visible data.
override
paint(Canvas canvas, Size size, double epochToX(int), double quoteToY(double), AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void
Paints seriesPainter's data on the canvas.
override
recalculateMinMax() List<double>
Calculate min/max values in updated data
override
shouldRepaint(ChartData? previous) bool
Checks if this ChartData needs to repaint with the chart widget's new frame.
override
toString() String
A string representation of this object.
inherited
update(int leftEpoch, int rightEpoch) → void
Updates visible entries for this Series.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited