AroonIndicatorConfig class
Aroon Indicator configurations.
- Inheritance
-
- Object
- AddOnConfig
- IndicatorConfig
- AroonIndicatorConfig
- Annotations
-
- @JsonSerializable.new()
Constructors
- AroonIndicatorConfig({int period = 14, LineStyle upLineStyle = const LineStyle(color: Colors.green), LineStyle downLineStyle = const LineStyle(color: Colors.red), int pipSize = 4, bool showLastIndicator = false, String? title, int number = 0})
-
Initializes
const
-
AroonIndicatorConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- configId → String?
-
Drawing tool config id.
finalinherited
- configSummary → String
-
Indicator config summary
no setterinherited
- downLineStyle → LineStyle
-
Down line style.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - number → int
-
The number of this add-on.
finalinherited
- period → int
-
The period
final
- pipSize → int
-
Number of digits after decimal point in price.
finalinherited
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortTitle → String
-
Short display title.
no setterinherited
- showLastIndicator → bool
-
Whether to show last indicator or not.
finalinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - title → String
-
The title of the indicator.
finalinherited
- upLineStyle → LineStyle
-
Up line style.
final
Methods
-
copyWith(
{int? period, LineStyle? upLineStyle, LineStyle? downLineStyle, int? pipSize, bool? showLastIndicator, String? title, int? number}) → AroonIndicatorConfig -
Creates a copy of this instance with given parameters.
override
-
getItem(
UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem -
Creates indicator UI.
override
-
getSeries(
IndicatorInput indicatorInput) → Series -
Creates indicator Series for the given
indicatorInput.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited