BarStyle class
Defines the style of painting histogram bar.
- Annotations
-
- @JsonSerializable.new()
- @ColorConverter.new()
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- negativeColor → Color
-
Color of histogram bar in which the price moved LOWER than the last epoch.
final
- positiveColor → Color
-
Color of histogram bar in which the price moved HIGHER than the
last epoch.
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{Color? positiveColor, Color? negativeColor}) → BarStyle - Creates a copy of this object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Parses this instance of BarStyle into a Map.
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited