longLine property
Barrier line start from screen edge or from the tick.
Will be ignored if the barrier has only an epoch or a value, and not both.
Implementation
final bool longLine;
Barrier line start from screen edge or from the tick.
Will be ignored if the barrier has only an epoch or a value, and not both.
final bool longLine;