BarrierStyle class abstract
Barrier style.
- Implementers
Constructors
- BarrierStyle({Color color = const Color(0xFF00A79E), Color titleBackgroundColor = const Color(0xFF0E0E0E), bool isDashed = true, TextStyle textStyle = const TextStyle(fontSize: 10, height: 1.3, fontWeight: FontWeight.normal, color: Colors.white, fontFeatures: <FontFeature>[FontFeature.tabularFigures()])})
-
Initializes a barrier style
const
Properties
- color → Color
-
Color of the barrier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDashed → bool
-
Whether barrier's line should be dashed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
Style of the title and value.
final
- titleBackgroundColor → Color
-
Title label background color.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited