CandleStyle class
Defines the style of painting candle data.
Constructors
- CandleStyle({Color candleBullishBodyColor = const Color(0xFF00C390), Color candleBearishBodyColor = const Color(0xFFDE0040), Color neutralColor = const Color(0xFF6E6E6E), Color candleBullishWickColor = const Color(0xFF00C390), Color candleBearishWickColor = const Color(0xFFDE0040)})
-
Initializes a style that defines the style of painting candle data.
const
Properties
- candleBearishBodyColor → Color
-
Color of candles in which the price moved LOWER during their period.
final
- candleBearishWickColor → Color
-
Color of wicks in which the price moved LOWER during their period.
final
- candleBullishBodyColor → Color
-
Color of candles in which the price moved HIGHER during their period.
final
- candleBullishWickColor → Color
-
Color of wicks in which the price moved HIGHER during their period.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- neutralColor → Color
-
Neutral color for candles in which the price remains same
or The vertical line inside candle which represents high/low.
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited