ChannelFillPainter class
A DataPainter for painting two line data and the channel fill inside of them.
- Inheritance
-
- Object
- SeriesPainter<
DataSeries< Tick> > - DataPainter<
DataSeries< Tick> > - ChannelFillPainter
Constructors
-
ChannelFillPainter(DataSeries<
Tick> firstSeries, DataSeries<Tick> secondSeries, {Color? firstUpperChannelFillColor, Color? secondUpperChannelFillColor}) - Initializes
Properties
- chartConfig ↔ ChartConfig
-
Chart's config.
getter/setter pairinherited
- chartScaleModel ↔ ChartScaleModel
-
Chart's scale model.
getter/setter pairinherited
-
firstSeries
→ DataSeries<
Tick> -
The first line series to be painting.
final
- firstUpperChannelFillColor ↔ Color?
-
The color for channel fill when firstSeries is the upper series.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secondSeries
→ DataSeries<
Tick> -
The second line series to be painting.
final
- secondUpperChannelFillColor ↔ Color?
-
The color for channel fill when secondSeries is the upper series.
getter/setter pair
-
series
→ DataSeries<
Tick> -
The Series which this SeriesPainter belongs to.
finalinherited
- theme ↔ ChartTheme
-
Chart's theme.
getter/setter pairinherited
Methods
-
getEpochOf(
Tick tick, int index) → int -
Gets the real epoch value for the given
tick.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPaint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo}) → void -
Paints DataSeries.visibleEntries on the
canvas.inherited -
onPaintData(
Canvas canvas, Size size, EpochToX epochToX, QuoteToY quoteToY, AnimationInfo animationInfo) → void -
Paints DataSeries.visibleEntries.
override
-
paint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo, required ChartConfig chartConfig, required ChartTheme theme, required ChartScaleModel chartScaleModel}) → void -
Sets some variables and paints this SeriesPainter's data.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited