ChartConfig class
Chart's general configuration.
- Annotations
-
- @immutable
- @JsonSerializable.new()
Constructors
- ChartConfig({required int granularity, ChartAxisConfig chartAxisConfig = const ChartAxisConfig(), int pipSize = 4, bool snapMarkersToIntervals = true})
-
Initializes chart's general configuration.
const
-
ChartConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- chartAxisConfig → ChartAxisConfig
-
Chart Axis configuration.
final
- granularity → int
-
Granularity.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- pipSize → int
-
PipSize, number of decimal digits when showing prices on the chart.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapMarkersToIntervals → bool
-
Whether markers' x-positions should snap to interval buckets (e.g., candle).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialization to JSON. Serves as value in key-value storage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
covariant ChartConfig other) → bool -
The equality operator.
override