ChartController class
Chart widget's controller.
Constructors
Properties
- getConfigsList ↔ GetConfigsList?
-
Called to get overlay and bottom configs
getter/setter pair
- getEpochFromX ↔ GetEpochFromX?
-
Called to get epoch from x position
getter/setter pair
- getMsPerPx ↔ GetMsPerPx?
-
Called to get msPerPx
getter/setter pair
- getQuoteFromY ↔ GetQuoteFromY?
-
Called to get quote from y position
getter/setter pair
- getSeriesList ↔ GetSeriesList?
-
Called to get overlay and bottom series
getter/setter pair
- getXFromEpoch ↔ GetXFromEpoch?
-
Called to get X position from epoch
getter/setter pair
- getYFromQuote ↔ GetQuoteFromY?
-
Called to get Y position from quote
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCompleteTickAnimation ↔ OnCompleteTickAnimation?
-
Called to complete the current tick animation immediately.
Used when resuming from background to skip stale animations.
getter/setter pair
- onScale ↔ GetQuoteFromY?
-
Called to scale the chart
getter/setter pair
- onScroll ↔ OnScroll?
-
Called to scroll the chart
getter/setter pair
- onScrollToLastTick ↔ OnScrollToLastTick?
-
Called to scroll the current display chart to last tick.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toggleDataFitMode ↔ ToggleDataFitMode?
-
Called to toggle data fit mode
getter/setter pair
- toggleXScrollBlock ↔ ToggleXScrollBlock?
-
Called to toggle a horizontal scroll block
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
double scale) → double? - Scales the chart.
-
scroll(
double pxShift) → void - Scroll chart visible area.
-
scrollToLastTick(
{bool animate = false}) → void - Scroll chart visible area to the newest data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited