paint abstract method
void
paint(
- Canvas canvas,
- Size size,
- EpochToX epochToX,
- QuoteToY quoteToY,
- AnimationInfo animationInfo,
- ChartConfig chartConfig,
- ChartTheme theme,
- ChartScaleModel chartScaleModel,
Paints this ChartData on the given canvas.
Size is the size of the canvas.
epochToX and quoteToY are conversion functions in the chart's
coordinate system. They respectively convert epoch to canvas X and quote
to canvas Y.
animationInfo Contains animations progress values in this frame of
painting.
ChartConfig is the chart's config which consist of
pipSizeNumber of decimal digits ChartData must use when showing their prices.granularityDuration of 1 candle in ms (for ticks: average ms difference between ticks).
theme Chart's theme
Implementation
void paint(
Canvas canvas,
Size size,
EpochToX epochToX,
QuoteToY quoteToY,
AnimationInfo animationInfo,
ChartConfig chartConfig,
ChartTheme theme,
ChartScaleModel chartScaleModel,
);