hasReducedOpacity property
Whether marker should be rendered with reduced opacity by 50%.
When set to true, marker will be rendered at half opacity. This is useful for indicating markers that represent future or unreached checkpoints in multi-stage contracts.
Defaults to false (full opacity).
Implementation
final bool hasReducedOpacity;