ChartObject class abstract
Any component other than chart data (line or candle) which can take a rectangle on the chart's canvas.
- Implementers
- Annotations
Constructors
- ChartObject(int? leftEpoch, int? rightEpoch, double? bottomValue, double? topValue)
-
Initializes
const
Properties
- bottomValue → double?
-
bottomValue
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- leftEpoch → int?
-
leftEpoch
final
- rightEpoch → int?
-
rightEpoch
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topValue → double?
-
topValue
final
Methods
-
isOnEpochRange(
int leftBoundEpoch, int rightBoundEpoch) → bool - Whether this chart object is in chart horizontal visible area.
-
isOnValueRange(
double bottomBoundValue, double topBoundValue) → bool - Whether this chart object is in chart horizontal visible area.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
covariant ChartObject other) → bool -
The equality operator.
override