textStyle abstract method
The style of text is generated by calling this function.
The textStyle argument must not be null, and if null is passed, an
ArgumentError will be thrown.
The color may be null or un-passed, in that case, a default value will
be assigned to it.
Implementation
TextStyle textStyle({required TextStyle textStyle, Color? color});