Series input list.
This is not the list that eventually will be painted. Sub-classes have the option to prepare their entries list which is the one that is painted from the input.
final List<T> input;