DrawingToolChart class
A widget for encapsulating drawing tools related business logic
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DrawingToolChart
Constructors
-
DrawingToolChart({required double chartQuoteFromCanvasY(double), required double chartQuoteToCanvasY(double), required DrawingTools drawingTools, required DataSeries<
Tick> series, Key? key}) -
Creates chart that expands to available space.
const
Properties
- chartQuoteFromCanvasY → double Function(double)
-
Conversion function for converting quote from chart's canvas' Y position.
final
- chartQuoteToCanvasY → double Function(double)
-
Conversion function for converting quote to chart's canvas' Y position.
final
- drawingTools → DrawingTools
-
Contains drawing tools related data and methods
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ DataSeries<
Tick> -
Series of tick
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DrawingToolChart> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited