DrawingToolWidget class

The class acts as a bridge between the selected drawing tool and the drawing creation process, delegating the specific creation logic to the corresponding drawing tool configurations.

Inheritance

Constructors

DrawingToolWidget({required void onAddDrawing(String drawingId, List<Drawing> drawingParts, {List<EdgePoint>? edgePoints, bool isDrawingFinished, bool isInfiniteDrawing}), required DrawingToolConfig selectedDrawingTool, required double quoteFromCanvasY(double), required VoidCallback clearDrawingToolSelection, required VoidCallback removeUnfinishedDrawing, required ChartConfig chartConfig, required DataSeries<Tick> series, bool? shouldStopDrawing, Key? key})
Initializes drawing creator area.
const

Properties

chartConfig ChartConfig
ChartConfig for getting pipsize
final
clearDrawingToolSelection VoidCallback
Callback to clean drawing tool selection.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAddDrawing → void Function(String drawingId, List<Drawing> drawingParts, {List<EdgePoint>? edgePoints, bool isDrawingFinished, bool isInfiniteDrawing})
Callback to pass a newly created drawing to the parent.
final
quoteFromCanvasY double Function(double)
Conversion function for converting quote to chart's canvas' Y position.
final
removeUnfinishedDrawing VoidCallback
Callback to remove unfinished drawing from the list of drawings.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDrawingTool DrawingToolConfig
Selected drawing tool.
final
series DataSeries<Tick>
Series of tick
final
shouldStopDrawing bool?
A flag to show when to stop drawing only for drawings which don't have fixed number of points like continuous drawing
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited