GatorSeries class
A series which shows Gator Series data calculated from 'entries'.
Constructors
- GatorSeries(IndicatorInput indicatorInput, {required AlligatorOptions gatorOptions, required GatorIndicatorConfig gatorConfig, BarStyle barStyle = const BarStyle(), String? id})
-
Initializes a series which shows shows Gator data calculated
from
indicatorInput.
Properties
- barStyle → BarStyle
-
Histogram bar style
final
- gatorBottomSeries ↔ SingleIndicatorSeries
-
Gator bottom series
getter/setter pair
- gatorConfig → GatorIndicatorConfig
-
Gator config
final
- gatorOptions ↔ AlligatorOptions
-
Gator options
getter/setter pair
- gatorTopSeries ↔ SingleIndicatorSeries
-
Gator top series
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
The ID of this ChartData.
getter/setter pairinherited
- maxValue → double
-
Max quote in a frame.
no setterinherited
- maxValueInFrame ↔ double?
-
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
- minValue → double
-
Min quote in a frame.
no setterinherited
- minValueInFrame ↔ double?
-
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seriesPainter
↔ SeriesPainter<
Series> ? -
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
- style → ChartPaintingStyle?
-
The painting style of this Series.
finalinherited
Methods
-
createPainter(
) → SeriesPainter< Series> ? -
Is called whenever series is created to create its seriesPainter
as well.
override
-
didUpdate(
ChartData? oldData) → bool -
Will be called by the chart when it was updated.
override
-
getMaxEpoch(
) → int? -
Maximum epoch of this ChartData on the chart's X-Axis.
override
-
getMinEpoch(
) → int? -
Minimum epoch of this ChartData on the chart's X-Axis.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onUpdate(
int leftEpoch, int rightEpoch) → void -
Updates series visible data.
override
-
paint(
Canvas canvas, Size size, double epochToX(int), double quoteToY(double), AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void -
Paints seriesPainter's data on the
canvas.override -
recalculateMinMax(
) → List< double> -
Calculate min/max values in updated data
override
-
shouldRepaint(
ChartData? previous) → bool -
Checks if this ChartData needs to repaint with the chart widget's
new frame.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int leftEpoch, int rightEpoch) → void -
Updates visible entries for this Series.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited