GridStyle class
For defining the style of the chart's grid. (X and Y axes).
Constructors
- GridStyle({Color gridLineColor = const Color(0x0A181C25), Color gridLineHighlightColor = const Color(0xFF262A2A), TextStyle xLabelStyle = const TextStyle(fontSize: 10, height: 2, fontWeight: FontWeight.normal, color: Color(0x3D181C25), fontFeatures: <FontFeature>[FontFeature.tabularFigures()]), TextStyle yLabelStyle = const TextStyle(fontSize: 10, height: 2, fontWeight: FontWeight.normal, color: Color(0x3D181C25), shadows: <Shadow>[Shadow(blurRadius: 4)], fontFeatures: <FontFeature>[FontFeature.tabularFigures()]), double labelHorizontalPadding = 8, double lineThickness = 1, double xLabelsAreaHeight = 24})
-
Initializes a style for defining the style of the chart's grid.
const
Properties
- gridLineColor → Color
-
The color of the grid lines.
final
- gridLineHighlightColor → Color
-
The color of grid lines for highlighting some points on the chart.
e.g. beginning of days/months.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelHorizontalPadding → double
-
Padding on the sides of the text label.
final
- lineThickness → double
-
The line thickness of the grid lines.
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - xLabelsAreaHeight → double
-
Height of the area for x-axis labels.
final
- xLabelStyle → TextStyle
-
The text style of the labels on time axes
final
- yLabelStyle → TextStyle
-
The text style of the value axes
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited