HorizontalBarrierPainter<T extends HorizontalBarrier> class
A class for painting horizontal barriers.
- Inheritance
-
- Object
- SeriesPainter<
T> - HorizontalBarrierPainter
- Implementers
Constructors
- HorizontalBarrierPainter(T series)
-
Initializes
series.
Properties
- chartConfig ↔ ChartConfig
-
Chart's config.
getter/setter pairinherited
- chartScaleModel ↔ ChartScaleModel
-
Chart's scale model.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- series → T
-
The Series which this SeriesPainter belongs to.
finalinherited
- theme ↔ ChartTheme
-
Chart's theme.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPaint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo}) → void -
Paints this SeriesPainter's data.
override
-
paint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo, required ChartConfig chartConfig, required ChartTheme theme, required ChartScaleModel chartScaleModel}) → void -
Sets some variables and paints this SeriesPainter's data.
inherited
-
paintLabelBackground(
Canvas canvas, Rect rect, LabelShape shape, Paint paint, {double radius = 4, Color? labelBackgroundColor}) → void - Paints a background based on the given LabelShape for the label text.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- rightMargin → const double
- Right margin.