HorizontalBarrierStyle class
Horizontal barrier style.
- Inheritance
-
- Object
- BarrierStyle
- HorizontalBarrierStyle
Constructors
- HorizontalBarrierStyle({LabelShape labelShape = LabelShape.rectangle, double labelHeight = 24, double labelPadding = 4, Color color = const Color(0xFF00A79E), Color titleBackgroundColor = const Color(0xFF0E0E0E), Color secondaryBackgroundColor = const Color(0xFF607D8B), bool isDashed = true, bool hasBlinkingDot = false, Color? blinkingDotColor, double arrowSize = 5, bool hasArrow = true, bool hasLine = true, Color labelShapeBackgroundColor = const Color(0xFF000000), Color lineColor = const Color(0xFF000000), TextStyle textStyle = const TextStyle(fontSize: 10, height: 1.3, fontWeight: FontWeight.normal, color: Colors.white, fontFeatures: <FontFeature>[FontFeature.tabularFigures()])})
-
Initializes a horizontal barrier style.
const
Properties
- arrowSize → double
-
The size of the arrow.
final
- blinkingDotColor → Color
-
The color of blinking dot.
final
- color → Color
-
Color of the barrier.
finalinherited
- hasArrow → bool
-
Whether to show an arrow pointing in the direction of the barrier,
when the barrier is outside the y-axis range and visibility is set to
HorizontalBarrierVisibility.keepBarrierLabelVisible.final - hasBlinkingDot → bool
-
Whether to have a blinking dot animation where barrier and chart data
are intersected.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLine → bool
-
Whether to draw a horizontal line to the current tick from the y-axis
grid to the
final
- isDashed → bool
-
Whether barrier's line should be dashed.
finalinherited
- labelHeight → double
-
Height of label background.
final
- labelPadding → double
-
Padding of label.
final
- labelShape → LabelShape
-
Label shape.
final
- labelShapeBackgroundColor → Color
-
Background color of the label shape.
final
- lineColor → Color
-
Color of the line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryBackgroundColor → Color
-
Color used to paint a second background of label if needed under the
initial color.
final
- textStyle → TextStyle
-
Style of the title and value.
finalinherited
- titleBackgroundColor → Color
-
Title label background color.
finalinherited
Methods
-
copyWith(
{LabelShape? labelShape, double? labelHeight, double? labelPadding, Color? color, Color? titleBackgroundColor, Color? secondaryBackgroundColor, bool? isDashed, bool? hasBlinkingDot, Color? blinkingDotColor, double? arrowSize, bool? hasArrow, bool? hasLine, Color? labelShapeBackgroundColor, Color? lineColor}) → HorizontalBarrierStyle - Creates a copy of this object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited