IconBarrierPainter class
The painter for the IconTickIndicator which paints the icon on the barrier's tick position.
- Inheritance
-
- Object
- SeriesPainter<
IconTickIndicator> - HorizontalBarrierPainter<
IconTickIndicator> - IconBarrierPainter
Constructors
- IconBarrierPainter(IconTickIndicator series)
- Initializes IconBarrierPainter.
Properties
- chartConfig ↔ ChartConfig
-
Chart's config.
getter/setter pairinherited
- chartScaleModel ↔ ChartScaleModel
-
Chart's scale model.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- series → IconTickIndicator
-
The Series which this SeriesPainter belongs to.
finalinherited
- theme ↔ ChartTheme
-
Chart's theme.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPaint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo}) → void -
Paints this SeriesPainter's data.
override
-
paint(
{required Canvas canvas, required Size size, required EpochToX epochToX, required QuoteToY quoteToY, required AnimationInfo animationInfo, required ChartConfig chartConfig, required ChartTheme theme, required ChartScaleModel chartScaleModel}) → void -
Sets some variables and paints this SeriesPainter's data.
inherited
-
paintLabelBackground(
Canvas canvas, Rect rect, LabelShape shape, Paint paint, {double radius = 4, Color? labelBackgroundColor}) → void -
Paints a background based on the given LabelShape for the label text.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited