InteractiveLayerDesktopBehaviour class
The Desktop-specific implementation of the interactive layer behaviour.
- Inheritance
-
- Object
- InteractiveLayerBehaviour
- InteractiveLayerDesktopBehaviour
Constructors
- InteractiveLayerDesktopBehaviour({InteractiveLayerController? controller})
- Creates an instance of InteractiveLayerDesktopBehaviour.
Properties
- controller → InteractiveLayerController
-
The controller for the interactive layer.
no setterinherited
- currentState → InteractiveState
-
Current state of the interactive layer.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactiveLayer ↔ InteractiveLayerBase
-
The interactive layer that this manager is managing.
getter/setter pairinherited
- onUpdate ↔ VoidCallback
-
The callback that is called when the interactive layer needs to be updated.
getter/setter pairinherited
-
previewDrawings
→ List<
DrawingV2> -
The extra drawings that the current interactive state can show in
InteractiveLayerBase.no setterinherited -
previewWidgets
→ List<
Widget> -
The extra widgets that the current interactive state can show on top of
interactive layer.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateChangeController ↔ AnimationController
-
The controller for state changes in the interactive layer.
getter/setter pairinherited
Methods
-
aNewToolsIsAdded(
InteractableDrawing< DrawingToolConfig> drawing) → void -
Will be called right after the process of startAddingTool is completed
without cancellation.
inherited
-
getAddingDrawingPreview(
InteractableDrawing< DrawingToolConfig> drawing, dynamic onAddingStateChange(AddingStateInfo)) → DrawingAddingPreview<InteractableDrawing< DrawingToolConfig> > -
Return the adding preview of the
drawingwe're currently adding for this Behaviour.override -
getToolState(
DrawingV2 drawing) → Set< DrawingToolState> -
The drawings of the interactive layer.
inherited
-
getToolZOrder(
DrawingV2 drawing) → DrawingZOrder -
Returns the z-order for the tool drawings.
inherited
-
hitTestDrawings(
Offset localPosition) → bool -
Checks if a point hits any drawing (both regular drawings and preview drawings).
inherited
-
init(
{required InteractiveLayerBase interactiveLayer, required VoidCallback onUpdate, required AnimationController stateChangeController}) → void -
Initializes the InteractiveLayerBehaviour.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onHover(
PointerHoverEvent event) → bool -
Handles hover event.
inherited
-
onLongPress(
Offset localPosition) → bool -
Handles long press event.
inherited
-
onLongPressEnd(
) → bool -
Handles long press end event.
inherited
-
onPanEnd(
DragEndDetails details) → bool -
Handles pan end event.
inherited
-
onPanStart(
DragStartDetails details) → bool -
Handles pan start event.
inherited
-
onPanUpdate(
DragUpdateDetails details) → bool -
Handles pan update event.
inherited
-
onTap(
TapUpDetails details) → bool -
Handles tap event.
inherited
-
startAddingTool(
DrawingToolConfig drawingTool) → void -
Handles the addition of a drawing tool.
Will be called when we want to add
drawingToolto the layer.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateStateTo(
InteractiveState newState, StateChangeAnimationDirection direction, {bool waitForAnimation = true, bool animate = true}) → Future< void> -
Updates the interactive layer state to the new state.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited