interactiveLayerBehaviour property
The interactive layer.
A reference to the layer that owns this state, allowing the state to access layer properties and methods.
Implementation
final InteractiveLayerBehaviour interactiveLayerBehaviour;
The interactive layer.
A reference to the layer that owns this state, allowing the state to access layer properties and methods.
final InteractiveLayerBehaviour interactiveLayerBehaviour;