MACDIndicatorConfig class
MACD Indicator Config
- Inheritance
-
- Object
- AddOnConfig
- IndicatorConfig
- MACDIndicatorConfig
- Annotations
-
- @JsonSerializable.new()
Constructors
- MACDIndicatorConfig({int fastMAPeriod = 12, int slowMAPeriod = 26, int signalPeriod = 9, BarStyle barStyle = const BarStyle(), LineStyle lineStyle = const LineStyle(color: Colors.white), LineStyle signalLineStyle = const LineStyle(color: Colors.redAccent), int pipSize = 4, bool showLastIndicator = false, String? title, int number = 0})
-
Initializes
const
-
MACDIndicatorConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- barStyle → BarStyle
-
Histogram bar style
final
- configId → String?
-
Drawing tool config id.
finalinherited
- configSummary → String
-
Indicator config summary
no setteroverride
- fastMAPeriod → int
-
The period to calculate the fast MA value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - lineStyle → LineStyle
-
Line style.
final
- number → int
-
The number of this add-on.
finalinherited
- pipSize → int
-
Number of digits after decimal point in price.
finalinherited
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortTitle → String
-
Short display title.
no setteroverride
- showLastIndicator → bool
-
Whether to show last indicator or not.
finalinherited
- signalLineStyle → LineStyle
-
Signal line style.
final
- signalPeriod → int
-
The period to calculate the Signal value.
final
- slowMAPeriod → int
-
The period to calculate the Slow MA value.
final
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - title → String
-
The title of the indicator.
no setteroverride
Methods
-
copyWith(
{int? fastMAPeriod, int? slowMAPeriod, int? signalPeriod, BarStyle? barStyle, LineStyle? lineStyle, LineStyle? signalLineStyle, int? pipSize, bool? showLastIndicator, String? title, int? number}) → MACDIndicatorConfig -
Creates a copy of this instance with given parameters.
override
-
getItem(
UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem -
Creates indicator UI.
override
-
getSeries(
IndicatorInput indicatorInput) → Series -
Creates indicator Series for the given
indicatorInput.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited