MarkerGroupSeries class
Marker Group series
A specialized series for displaying groups of related markers on a chart. This class extends MarkerSeries and provides functionality for managing and displaying collections of MarkerGroup objects.
MarkerGroupSeries is responsible for determining which marker groups should be visible based on the current chart viewport (defined by leftEpoch and rightEpoch).
- Inheritance
-
- Object
- Series
- MarkerSeries
- MarkerGroupSeries
Constructors
-
MarkerGroupSeries(SplayTreeSet<
Marker> entries, {required MarkerGroupIconPainter markerGroupIconPainter, List<MarkerGroup> ? markerGroupList, ActiveMarkerGroup? activeMarkerGroup, ActiveMarker? activeMarker}) - Initializes a new instance of the MarkerGroupSeries class.
Properties
- activeMarker → ActiveMarker?
-
Active/focused marker on the chart.
finalinherited
- activeMarkerGroup → ActiveMarkerGroup?
-
Active marker group that is currently selected on the chart.
final
- axisGroup → String?
-
Which axis this series scales against.
finalinherited
- entryTick → Tick?
-
Entry tick marker.
finalinherited
- exitTick → Tick?
-
Exit tick marker.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
The ID of this ChartData.
getter/setter pairinherited
- markerGroupIconPainter → MarkerGroupIconPainter
-
Painter that draws corresponding marker icons.
final
-
markerGroupList
→ List<
MarkerGroup> ? -
List of related grouped markers.
final
- markerIconPainter → MarkerIconPainter
-
Painter that draw corresponding marker icon.
finalinherited
- maxValue → double
-
Max quote in a frame.
no setterinherited
- maxValueInFrame ↔ double?
-
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
- minValue → double
-
Min quote in a frame.
no setterinherited
- minValueInFrame ↔ double?
-
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seriesPainter
↔ SeriesPainter<
Series> ? -
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
- style → ChartPaintingStyle?
-
The painting style of this Series.
finalinherited
-
visibleEntries
↔ List<
Marker> -
Visible marker entries.
getter/setter pairinherited
-
visibleMarkerGroupList
↔ List<
MarkerGroup> -
List of marker groups that are currently visible in the chart viewport.
getter/setter pair
Methods
-
createPainter(
) → SeriesPainter< MarkerGroupSeries> -
Creates a painter for rendering this marker group series on the chart.
override
-
didUpdate(
ChartData? oldData) → bool -
Always returns false because marker changes do not drive tick animations;
only the main series result is used for that purpose.
inherited
-
getMaxEpoch(
) → int? -
Maximum epoch of this ChartData on the chart's X-Axis.
inherited
-
getMinEpoch(
) → int? -
Minimum epoch of this ChartData on the chart's X-Axis.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTap(
Offset localPosition) → bool -
Called when this series' pane receives a tap at
localPosition, in the same coordinate space as paint'ssize/canvas. Override to make a drawn region (e.g. a label) interactive. Returnstrueif the tap was handled by this series.inherited -
onUpdate(
int leftEpoch, int rightEpoch) → void -
Updates the list of visible marker groups based on the current chart viewport.
override
-
paint(
Canvas canvas, Size size, double epochToX(int), double quoteToY(double), AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void -
Paints seriesPainter's data on the
canvas.inherited -
recalculateMinMax(
) → List< double> -
Calculate min/max values in updated data
inherited
-
shouldRepaint(
ChartData? previous) → bool -
Checks if this ChartData needs to repaint with the chart widget's
new frame.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int leftEpoch, int rightEpoch) → void -
Updates visible entries for this Series.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited