MarkerSeries class
Marker series
- Inheritance
- Implementers
Constructors
-
MarkerSeries(SplayTreeSet<
Marker> entries, {required MarkerIconPainter markerIconPainter, String? id, MarkerStyle? style, ActiveMarker? activeMarker, Tick? entryTick, Tick? exitTick}) - Initializes.
Properties
- activeMarker → ActiveMarker?
-
Active/focused marker on the chart.
final
- axisGroup → String?
-
Which axis this series scales against.
finalinherited
- entryTick → Tick?
-
Entry tick marker.
final
- exitTick → Tick?
-
Exit tick marker.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
The ID of this ChartData.
getter/setter pairinherited
- markerIconPainter → MarkerIconPainter
-
Painter that draw corresponding marker icon.
final
- maxValue → double
-
Max quote in a frame.
no setterinherited
- maxValueInFrame ↔ double?
-
Maximum value of this series in a visible range of the chart.
getter/setter pairinherited
- minValue → double
-
Min quote in a frame.
no setterinherited
- minValueInFrame ↔ double?
-
Minimum value of this series in a visible range of the chart.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seriesPainter
↔ SeriesPainter<
Series> ? -
Responsible for painting a frame of this series on the canvas.
getter/setter pairinherited
- style → ChartPaintingStyle?
-
The painting style of this Series.
finalinherited
-
visibleEntries
↔ List<
Marker> -
Visible marker entries.
getter/setter pair
Methods
-
createPainter(
) → SeriesPainter< MarkerSeries> -
Is called whenever series is created to create its seriesPainter
as well.
override
-
didUpdate(
ChartData? oldData) → bool -
Always returns false because marker changes do not drive tick animations;
only the main series result is used for that purpose.
override
-
getMaxEpoch(
) → int? -
Maximum epoch of this ChartData on the chart's X-Axis.
override
-
getMinEpoch(
) → int? -
Minimum epoch of this ChartData on the chart's X-Axis.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onUpdate(
int leftEpoch, int rightEpoch) → void -
Updates series visible data.
override
-
paint(
Canvas canvas, Size size, double epochToX(int), double quoteToY(double), AnimationInfo animationInfo, ChartConfig chartConfig, ChartTheme theme, ChartScaleModel chartScaleModel) → void -
Paints seriesPainter's data on the
canvas.inherited -
recalculateMinMax(
) → List< double> -
Calculate min/max values in updated data
override
-
shouldRepaint(
ChartData? previous) → bool -
Checks if this ChartData needs to repaint with the chart widget's
new frame.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int leftEpoch, int rightEpoch) → void -
Updates visible entries for this Series.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited