Market class
A class to keep a market's information.
Constructors
-
Market({required List<
SubMarket?> subMarkets, String name = '', String? displayName}) - Creates a class to keep a market's information.
-
Market.fromAssets({required String name, required String displayName, required List<
Asset> assets}) -
Creates a market from a given
listof assets. -
Market.fromSubMarketAssets({required String name, required String displayName, required List<
Asset?> assets}) - Creates one market with one submarket from the given assets.
Properties
- displayName → String
-
The displaying name of the market.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the market.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subMarkets
→ List<
SubMarket?> -
The list of submarkets that go under this market.
final
Methods
-
containsAssetWithText(
String text) → bool -
Returns true if any asset under this market contains the
text. -
containsText(
String text) → bool -
Checks if the displayName contains the given
text -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited