OscillatorLinesConfig class
Oscillator Limits.
- Annotations
-
- @JsonSerializable.new()
Constructors
- OscillatorLinesConfig({required double overboughtValue, required double oversoldValue, LineStyle overboughtStyle = const LineStyle(thickness: 0.5), LineStyle oversoldStyle = const LineStyle(thickness: 0.5)})
-
Initializes
const
-
OscillatorLinesConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- overboughtStyle → LineStyle
-
The overbought line style.
final
- overboughtValue → double
-
The price to show the over bought line.
final
- oversoldStyle → LineStyle
-
The oversold line style.
final
- oversoldValue → double
-
The price to show the over sold line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? overboughtValue, double? oversoldValue, LineStyle? overboughtStyle, LineStyle? oversoldStyle}) → OscillatorLinesConfig - copyWith implementation for OscillatorLinesConfig
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Parses this instance of OscillatorLinesConfig into a Map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited