SMIIndicatorConfig class
SMI Indicator configurations.
- Inheritance
-
- Object
- AddOnConfig
- IndicatorConfig
- SMIIndicatorConfig
- Annotations
-
- @JsonSerializable.new()
Constructors
- SMIIndicatorConfig({int period = 10, int smoothingPeriod = 3, int doubleSmoothingPeriod = 3, int signalPeriod = 10, OscillatorLinesConfig smiOscillatorLimits = const OscillatorLinesConfig(oversoldValue: -40, overboughtValue: 40, overboughtStyle: LineStyle(), oversoldStyle: LineStyle()), MovingAverageType maType = MovingAverageType.exponential, bool showZones = true, LineStyle? lineStyle, LineStyle? signalLineStyle, int pipSize = 4, bool showLastIndicator = false, String? title, int number = 0})
-
Initializes
const
-
SMIIndicatorConfig.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
- configId → String?
-
Drawing tool config id.
finalinherited
- configSummary → String
-
Indicator config summary
no setterinherited
- doubleSmoothingPeriod → int
-
double smoothing period.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOverlay → bool
-
Whether the add-on is an overlay on the main chart or displays on a
separate chart. Default is set to
true.finalinherited - lineStyle → LineStyle?
-
Line style.
final
- maType → MovingAverageType
-
/// The Moving Average type of SMI signal (D%).
final
- number → int
-
The number of this add-on.
finalinherited
- period → int
-
The period to calculate the average gain and loss.
final
- pipSize → int
-
Number of digits after decimal point in price.
finalinherited
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortTitle → String
-
Short display title.
no setterinherited
- showLastIndicator → bool
-
Whether to show last indicator or not.
finalinherited
- showQuoteGrid → bool
-
Whether to show the y-axis quote grid (lines + labels) for this
indicator's pane.
finalinherited
- showZones → bool
-
Whether to show zones (intersection between indicator and overbought/sold).
final
- signalLineStyle → LineStyle?
-
Signal line style.
final
- signalPeriod → int
-
The period of SMI signal (D%).
final
- smiOscillatorLimits → OscillatorLinesConfig
-
Oscillator limit lines
final
- smoothingPeriod → int
-
Smoothing period.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - title → String
-
The title of the indicator.
finalinherited
Methods
-
copyWith(
{int? period, int? smoothingPeriod, int? doubleSmoothingPeriod, int? signalPeriod, MovingAverageType? maType, OscillatorLinesConfig? smiOscillatorLimits, bool? showZones, LineStyle? lineStyle, LineStyle? signalLineStyle, int? pipSize, bool? showLastIndicator, String? title, int? number}) → SMIIndicatorConfig -
Creates a copy of this instance with given parameters.
override
-
getItem(
UpdateIndicator updateIndicator, VoidCallback deleteIndicator) → IndicatorItem -
Creates indicator UI.
override
-
getSeries(
IndicatorInput indicatorInput) → Series -
Creates indicator Series for the given
indicatorInput.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serialization to JSON. Serves as value in key-value storage.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited