ScatterStyle class
Defines the style of painting Scatter data.
- Annotations
-
- @JsonSerializable.new()
- @ColorConverter.new()
Constructors
- ScatterStyle({Color color = const Color(0xFF85ACB0), double radius = 1.5})
-
Initializes a style that defines the style of painting line data.
const
-
ScatterStyle.fromJson(Map<
String, dynamic> json) -
Initializes from JSON.
factory
Properties
Methods
-
copyWith(
{Color? color, double? radius}) → ScatterStyle - Creates a copy of this object.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Parses this instance of ScatterStyle into a Map.
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited