paintOverYAxis method
void
paintOverYAxis(
- Canvas canvas,
- Size size,
- EpochToX epochToX,
- QuoteToY quoteToY,
- EpochFromX? epochFromX,
- QuoteFromY? quoteFromY,
- AnimationInfo animationInfo,
- ChartConfig chartConfig,
- ChartTheme chartTheme,
- GetDrawingState getDrawingState,
override
Paints the drawing tool chart but over the Y-axis.
This is useful for the drawing wants to paint something that should be visible over the Y-axis, like a horizontal line or a label.
Implementation
@override
void paintOverYAxis(
Canvas canvas,
Size size,
EpochToX epochToX,
QuoteToY quoteToY,
EpochFromX? epochFromX,
QuoteFromY? quoteFromY,
AnimationInfo animationInfo,
ChartConfig chartConfig,
ChartTheme chartTheme,
GetDrawingState getDrawingState,
) {
if (_hoverPosition != null && epochFromX != null && quoteFromY != null) {
drawPointGuidesAndLabels(
canvas,
size,
_hoverPosition!,
epochToX,
quoteToY,
epochFromX,
quoteFromY,
chartConfig,
chartTheme,
showGuides: false,
);
}
}