ChartLocalization class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelBandsCount → String
-
Bands Countno setter - labelBaseLinePeriod → String
-
Base Line Periodno setter - labelChannelFill → String
-
Channel Fillno setter - labelColor → String
-
Colorno setter - labelConversionLinePeriod → String
-
Conversion Line Periodno setter - labelDistance → String
-
Distanceno setter - labelDoubleSmoothingPeriod → String
-
Double Smoothing Periodno setter - labelFastMAPeriod → String
-
Fast MA Periodno setter - labelField → String
-
Fieldno setter - labelFillColor → String
-
Fill Colorno setter - labelHighPeriod → String
-
High Periodno setter - labelHistogram → String
-
Histogramno setter - labelIsSmooth → String
-
Is Smoothno setter - labelJawOffset → String
-
Jaw Offsetno setter - labelJawPeriod → String
-
Jaw Periodno setter - labelLaggingSpanOffset → String
-
Lagging Span Offsetno setter - labelLipsOffset → String
-
Lips Offsetno setter - labelLipsPeriod → String
-
Lips Periodno setter - labelLowPeriod → String
-
Low Periodno setter - labelMaxAF → String
-
Max AFno setter - labelMinAF → String
-
Min AFno setter - labelOffset → String
-
Offsetno setter - labelOverBoughtPrice → String
-
Over Bought Priceno setter - labelOverSoldPrice → String
-
Over Sold Priceno setter - labelPeriod → String
-
Periodno setter - labelSearchAssets → String
-
Search assetsno setter - labelSeries → String
-
Seriesno setter - labelShading → String
-
Shadingno setter - labelShift → String
-
Shiftno setter - labelShiftType → String
-
Shift Typeno setter - labelShowFractals → String
-
Show Fractalsno setter - labelShowLines → String
-
Show Linesno setter - labelShowZones → String
-
Show Zonesno setter - labelSignalPeriod → String
-
Signal Periodno setter - labelSlowMAPeriod → String
-
Slow MA Periodno setter - labelSmoothingPeriod → String
-
Smoothing Periodno setter - labelSpanBPeriod → String
-
Leading Span B Periodno setter - labelStandardDeviation → String
-
Standard Deviationno setter - labelTeethOffset → String
-
Teeth Offsetno setter - labelTeethPeriod → String
-
Teeth Periodno setter - labelType → String
-
Typeno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectDrawingTool → String
-
Select drawing toolno setter - warnCheckAssetSearchingText → String
-
Try checking your spelling or use a different termno setter - warnFailedLoadingDrawingTools → String
-
Failed to load drawing tools.no setter - warnFailedLoadingIndicators → String
-
Failed to load indicators.no setter
Methods
-
informNoResult(
Object text) → String -
No results for "{text}" -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- current → ChartLocalization
-
no setter
Static Methods
-
load(
Locale locale) → Future< ChartLocalization> -
maybeOf(
BuildContext context) → ChartLocalization? -
of(
BuildContext context) → ChartLocalization
Constants
- delegate → const AppLocalizationDelegate